version 7
set matsize 120
tempfile coeff profit lntfp brazskil

local yrmax=98

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


confirm new file "brazcomp\data\use-firms-`ext'.dta"


/* Variables from brazprod coefficients */
/*--------------------------------------*/

use "brazprod\estimate\coeff-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
keep firm year indsurvv lnvaladd kappa1 kappa0 mu betakappa betamu lnapk1 lnapq1
foreach var in mu betakappa betamu lnapk1 lnapq1 {
  rename `var' _`var'
  }
gen valadd = exp(lnvaladd)
label var valadd "Value Added"
drop lnvaladd
sort firm year
order firm year indsurvv valadd kappa1 kappa0 
compress
save `coeff'


/* Profit figures from raw brazprod data */
/*---------------------------------------*/

use "brazprod\data\deflated\pia-flows-`ext'-1-ipa-indtot", clear
keep firm year prof*
sort firm year
merge firm year using "brazprod\data\pia-ratios"
keep firm year prof* prf*
sort firm year
save `profit'


/* Variables from brazskil/brazprod data */
/*---------------------------------------*/

use "brazprod/data/prodlevel-op-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
keep firm year lntfp lnlp 
sort firm year
compress
save `lntfp'

* XXX use "brazskil\data\prep\firms", clear
* XXX keep firm year manyrs* wages*
* XXX forvalues i = 1/9 {
* XXX   rename wages`i' wage`i'
* XXX   }
* XXX sort firm year
* XXX compress
* XXX save `brazskil'

/* Obtain PIA Data */
/*-----------------*/

use "brazprod\use-compl-`ext'`fdfl'", clear
keep  firm year indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1x acqtot asltot apimmo0x apmasm1x acqmasum acqmafor aslmasum apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x acqcomp aslcomp apcomp0x apimmo1r aslsimmo asrtimmo crrat crltrat crforrat crtot profit niv100 indtype region uf reffpen tariff tariffrx inflrate realexch 
sort firm year
merge firm year using `coeff', nokeep
drop _merge
sort firm year
merge firm year using `profit', nokeep
drop _merge
gen prfaprat = profit/apimmo1x
label var prfaprat "Ratio: Profit (bef. tax)/Capital"
order firm year indexp indsurvv indexit indsusp indresum indmoth age sales exports difstock valadd wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1x acqtot asltot apimmo0x apmasm1x acqmasum acqmafor aslmasum apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x acqcomp aslcomp apcomp0x apimmo1r aslsimmo asrtimmo kappa1 kappa0 crrat crltrat crforrat crtot profit profoutd profinpd prfaprat prfslrat niv100 indtype region uf reffpen tariff tariffrx inflrate realexch 

sort firm year
merge firm year using `lntfp', nokeep
gen lntfpsub = .
label var lntfpsub "Log TFP less kappa and mu eff."
replace lntfpsub = lntfp - _betakappa*kappa1 if _betakappa>=0
replace lntfpsub = lntfp - _betamu*_mu if _betamu>=0
order firm year indexp indsurvv indexit indsusp indresum indmoth age sales exports difstock valadd wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1x acqtot asltot apimmo0x apmasm1x acqmasum acqmafor aslmasum apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x acqcomp aslcomp apcomp0x apimmo1r aslsimmo asrtimmo kappa1 kappa0 crrat crltrat crforrat crtot profit profoutd profinpd prfaprat prfslrat lntfp lntfpsub lnlp niv100 indtype region uf reffpen tariff tariffrx inflrate realexch 

egen _labftot=rsum(labfbl labfwh)
gen byte dlbfmed=1 if _labftot>=30 & _labftot<300
replace  dlbfmed=0 if dlbfmed~=1
label var dlbfmed "Indic. Labor Force >=30"
gen byte dlbfbig=1 if _labftot>=300
replace  dlbfbig=0 if dlbfbig~=1
label var dlbfbig "Indic. Labor Force >=300"
gen _apk1=exp(_lnapk1)
gen _apq1=exp(_lnapq1)
egen _ap=rsum(_apk1 _apq1)
egen _lowpctle=pctile(_ap), p(33)
egen _uprpctle=pctile(_ap), p(67)
gen byte dcapmed= (_ap>_lowpctle & _ap<=_uprpctle)
label var dcapmed "Indic. Medium Capital Stock"
gen byte dcapbig= (_ap>_uprpctle)
label var dcapbig "Indic. Large Capital Stock"
drop _*
order firm year indexp indsurvv indexit indsusp indresum indmoth age sales exports difstock valadd wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1x acqtot asltot apimmo0x apmasm1x acqmasum acqmafor aslmasum apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x acqcomp aslcomp apcomp0x apimmo1r aslsimmo asrtimmo kappa1 kappa0 crrat crltrat crforrat crtot profit profoutd profinpd prfaprat prfslrat lntfp lntfpsub lnlp dlbfmed dlbfbig dcapmed dcapbig niv100 indtype region uf reffpen tariff tariffrx inflrate realexch

* XXX sort firm year
* XXX merge firm year using `brazskil', nokeep
* XXX drop _merge

/* Check consistency with prep-final.do */
order firm year indexp indsurvv indexit indsusp indresum indmoth age sales exports difstock valadd wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1x acqtot asltot apimmo0x apmasm1x acqmasum acqmafor aslmasum apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x acqcomp aslcomp apcomp0x apimmo1r aslsimmo asrtimmo kappa1 kappa0 crrat crltrat crforrat crtot profit profoutd profinpd prfaprat prfslrat lntfp lntfpsub lnlp dlbfmed dlbfbig dcapmed dcapbig niv100 indtype region uf reffpen tariff tariffrx inflrate realexch /* XXX manyrs1 manyrs2 manyrs3 manyrs4 manyrs5 manyrs6 manyrs7 manyrs8 manyrs9 wage1 wage2 wage3 wage4 wage5 wage6 wage7 wage8 wage9 XXX */

compress
sort firm year
save "brazcomp\data\use-firms-`ext'`fdfl'", replace
