version 6.0

/* Niv80: NIV10080 */
insheet using "brazprod\filters\tradprod.csv", clear
drop in 1
drop in 546
rename v1 niv100
rename v2 niv80
replace niv100=substr(niv100,1,5)
replace niv80=substr(niv80,1,4)
gen int rniv100=real(niv100)
gen int rniv80=real(niv80)
drop niv100 niv80
rename rniv100 niv100or
rename rniv80 niv80
drop if niv100or==.
gen int niv100=int(niv100or/10)
egen grp=group(niv80 niv100)
egen mingrp=min(grp), by(niv100)
egen maxgrp=max(grp), by(niv100)
gen overlaps=maxgrp-mingrp
sort niv100 niv80
drop grp mingrp maxgrp
egen min80=min(niv80), by (niv100 overlaps)
egen max80=max(niv80), by (niv100 overlaps)
sort niv100 overlaps
quietly by niv100 overlaps: gen int nivmap=max80
egen min80mp=min(nivmap), by(niv80)
egen max80mp=max(nivmap), by(niv80)
replace nivmap=. if min80mp~=max80mp
drop min80mp max80mp niv100or overlaps min80 max80
sort niv100 niv80 nivmap
quietly by niv100 niv80 nivmap: keep if _n==1
sort niv100 niv80
save "brazprod\filters\niv10080.dta", replace

/* Datas de nascimento: CGC-NASC */
tempfile census pia96 pia97 pia98
insheet using "brazprod\cgc-list\cgc-nasc.csv", clear
keep cgc ano
rename ano yrborn
drop if cgc==. | yrborn==.
replace yrborn=yrborn+1000
drop if yrborn<1600
sort yrborn
save `census'
capture program drop cgcprep
program define cgcprep
 args yr tmpfile
 insheet using "brazprod\cgc-list\pia`yr'-nasc.csv", clear
 drop cnae
 rename empresa cgc
 rename anofund yrborn`yr'
 sort yrborn`yr'
 save `tmpfile'
end
cgcprep 96 `pia96'
cgcprep 97 `pia97'
cgcprep 98 `pia98'
use `census', clear
joinby cgc using `pia96', _merge(_merge96) unmatched(both)
joinby cgc using `pia97', _merge(_merge97) unmatched(both)
joinby cgc using `pia98', _merge(_merge98) unmatched(both)
order cgc yrborn yrborn96 yrborn97 yrborn98 _merge96 _merge97 _merge98
drop _merge96-_merge98
gen int born=yrborn98             /* From CAD3 */
replace born=yrborn97 if born==.  /* From CAD2 */
replace born=yrborn96 if born==.  /* From CAD1 */
replace born=yrborn if (born==1965 & yrborn<born) | (born==1966 & yrborn<born) /* Replacement if birthdate in CAD is 1965 or 66 while M001 indicates earlier birth */
replace born=yrborn if born==.    /* From M001 */
label var born "Founding Year of Firm"
keep cgc born     /* Drop this line for Aline comparison */
rename cgc firm   /* Drop this line for Aline comparison */
format born %4.0f
sort firm
save "brazprod\cgc-list\cgc-nasc.dta", replace

/* CNAE to Niv100 from pia.tex for comparison */
insheet using "brazprod\filters\cnae-niv100-piatex.txt", comma clear
rename v1 nivel100
drop v2
forvalues num = 3/28 {
    local newnum = `num' - 2
    rename v`num' cnae`newnum'
    }
reshape long cnae, i(nivel100) j(rep)
drop if cnae==.
compress
sort cnae
order cnae nivel100
save "brazprod\filters\cnae-niv100", replace
drop rep
sort nivel100
order nivel100 cnae
outsheet using "brazprod\filters\cnae-niv100-piatex.csv", comma replace

/* CNAE to Niv100 from original "NVEL 100 x CNAE citando N100 PIM-PF.rtf" */
insheet using "brazprod\filters\cnae-niv100-orig.csv", comma clear
rename v1 nivel100
gen str10 remark = ""
replace remark = v2 if _n==_N
gen v2real = real(v2)
drop v2
rename v2real v2
order nivel v* rem
forvalues num = 2/27 {
    local newnum = `num' - 1
    rename v`num' cnae`newnum'
    }
reshape long cnae, i(nivel100) j(rep)
drop if cnae==. & remark==""
sort cnae nivel100 remark
by cnae nivel100 remark: keep if _n==1
compress
sort cnae
order cnae nivel100
drop rep
save "brazprod\filters\cnae-niv100", old replace
sort nivel100
order nivel100 cnae
outsheet using "brazprod\filters\cnae-niv100.csv", comma replace
