version 7
set matsize 180

tempfile oecdsec niv100 conc

/* Niv100 - OECD filter */
/*----------------------*/

insheet using "brazprod/filters/oecd-ppi.csv", comma clear
rename v1 oecdsec
rename v2 oecdsec_desc
sort oecdsec
compress
save `oecdsec'

/* Prepare English list of Niv100 definitions */
insheet using "brazprod/filters/niv100.csv", comma clear
gen byte number=_n
rename v1 niv100
rename v2 niv100_en
label var niv100 "Nivel 100"
label var niv100_en "English Nivel 100 definition"
sort number
drop number
rename niv100_en nivdesc
compress
save "brazprod/filters/nivdef", replace
sort niv100
compress
save `niv100'

insheet using "brazprod/filters/niv100-oecd-ppi.csv", comma clear
rename oecdppi oecdsec
drop if oecdsec==.
drop if niv100==.
sort oecdsec
joinby oecdsec using `oecdsec', unmatched(master) _merge(_merge)
drop _merge
sort niv100
joinby niv100 using `niv100', unmatched(master) _merge(_merge)
drop _merge
order niv100 oecdsec nivdesc oecdsec_desc
sort niv100
compress
label var niv100  "Nivel 100"
label var oecdsec "Sector definition OECD PPI"
label var oecdsec_desc "Sector description OECD PPI"
compress
save "brazprod/filters/niv100-oecd-conc", replace
preserve
    gen str6 niv100str = string(niv100) + " &"
    gen str7 oecdstr = string(oecdsec) + " &"
    replace oecdsec_desc = upper(substr(oecdsec_desc,1,1)) + lower(substr(oecdsec_desc,2,.)) + " \" + "\"
    label var oecdstr "OECD sector definitions"
    label var niv100str "Nivel 100 (IBGE)"
    drop nivdesc niv100 oecdsec
    order oecdstr niv100str oecdsec_desc
    sort oecdstr niv100str
    capture outsheet using "c:/texdocs/brazcomp/brsecdef/stata-origs/niv100-oecd-conc.tex", noquote nonames replace
restore

/* Raw PPI series */
/*----------------*/

insheet using "brazprod/addl/ivs/ppi-oecd/oecd-use.csv", comma clear
drop in 2
drop in 1
rename v1 country
drop if country=="North America" | country=="European Union" | country=="OECD-Europe" | country=="OECD-Total"
local i 1
foreach ind in 0 2 3 31 3112 313 314 32 321 322 323 324 33 34 3411 342 35 3512 353 36 362 37 371 372 38 381 382 383 384 3841 3843 4 {
  foreach yr in 86 87 88 89 90 91 92 93 94 95 96 97 98 {
    local i = `i' + 1
    qui replace v`i' = "." if v`i'=="-"
    qui gen ind`ind'yr`yr' = real(v`i')
    qui drop v`i' 
    }
  }
compress
reshape long ind0yr ind2yr ind3yr ind31yr ind3112yr ind313yr ind314yr ind32yr ind321yr ind322yr ind323yr ind324yr ind33yr ind34yr ind3411yr ind342yr ind35yr ind3512yr ind353yr ind36yr ind362yr ind37yr ind371yr ind372yr ind38yr ind381yr ind382yr ind383yr ind384yr ind3841yr ind3843yr ind4yr, i(country) j(year)
foreach var in ind0 ind2 ind3 ind31 ind3112 ind313 ind314 ind32 ind321 ind322 ind323 ind324 ind33 ind34 ind3411 ind342 ind35 ind3512 ind353 ind36 ind362 ind37 ind371 ind372 ind38 ind381 ind382 ind383 ind384 ind3841 ind3843 ind4 {
  rename `var'yr `var'
  }

capture program drop repldwn
program define repldwn
  args upind dwnind
  foreach ind in `dwnind' { 
    egen _chkallmiss = sum(ind`ind'), by(country)
    replace ind`ind' = ind`upind' if _chkallmiss==0
    drop _*
    }
end
capture program drop replup
program define replup
  args upind dwnind
  egen _chkallmiss = sum(ind`upind'), by(country)
  egen _meanlwlvl  = rmean(`dwnind')
  replace ind`upind' = _meanlwlvl if _chkallmiss==0
  drop _*
end

repldwn 31  "3112 313 314"
repldwn 32  "321 322 323 324"
repldwn 34  "3411 342"
repldwn 35  "3512 353"
repldwn 36  "362"
repldwn 37  "371 372"
repldwn 38  "381 382 383 384"
repldwn 384 "3841 3843"

replup 31  "ind3112 ind313 ind314"
replup 32  "ind321 ind322 ind323 ind324"
replup 34  "ind3411 ind342"
replup 35  "ind3512 ind353"
replup 36  "ind362"
replup 37  "ind371 ind372"
replup 384 "ind3841 ind3843"
replup 38  "ind381 ind382 ind383 ind384"

capture program drop fillup
program define fillup
  args upind dwnind
  sort country year
  egen _meanlwlvl  = rmean(`dwnind')
  foreach year in 89 88 87 86 {
    replace ind`upind' = (_meanlwlvl/_meanlwlvl[_n+1])*ind`upind'[_n+1] if year==`year' & ind`upind'==.
  }
  foreach year in 91 92 93 94 95 96 97 98 {
    replace ind`upind' = (_meanlwlvl/_meanlwlvl[_n-1])*ind`upind'[_n-1] if year==`year' & ind`upind'==.
  }
  drop _*
end
capture program drop filldwn
program define filldwn
  args upind dwnind
  sort country year
  foreach ind in `dwnind' {
    foreach year in 89 88 87 86 {
      replace ind`ind' = (ind`upind'/ind`upind'[_n+1])*ind`ind'[_n+1] if year==`year' & ind`ind'==.
    }
    foreach year in 91 92 93 94 95 96 97 98 {
      replace ind`ind' = (ind`upind'/ind`upind'[_n-1])*ind`ind'[_n-1] if year==`year' & ind`ind'==.
    }
  }
end

fillup 31  "ind3112 ind313 ind314"
fillup 32  "ind321 ind322 ind323 ind324"
fillup 34  "ind3411 ind342"
fillup 35  "ind3512 ind353"
fillup 36  "ind362"
fillup 37  "ind371 ind372"
fillup 384 "ind3841 ind3843"
fillup 38  "ind381 ind382 ind383 ind384"

filldwn 31  "3112 313 314"
filldwn 32  "321 322 323 324"
filldwn 34  "3411 342"
filldwn 35  "3512 353"
filldwn 36  "362"
filldwn 37  "371 372"
filldwn 38  "381 382 383 384"
filldwn 384 "3841 3843"

reshape long ind, i(country year) j(oecdsec)
rename ind ppi

egen _chkallmiss = sum(ppi), by(country)
drop if _chkallmiss==0
drop _*

order country oecdsec year ppi
sort country oecdsec year
compress
label var country "Country"
label var oecdsec "Sector definition OECD PPI"
label var year "Calendar Year"
label var ppi "PPI: OECD Indic Indstry & Servcs"
compress
save "brazprod/addl/ivs/ppi-oecd/oecd-ppi", replace
