version 7
set matsize 200

tempfile master tmp7 forppi
tempfile capf86 capf87 capf88 capf89 capf90 capf91 capf92 capf93 capf94 capf95 capf96 capf97 capf98 capf99
tempfile c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99
tempfile cap1 cap2 cap3 cap4 cap5

/* Produced Deflators  1: Mesquita (and general) Deflators 90-98 */
/*                     2: PIM-IBGE (and general) Deflators 86-98 */
/*                     3: FGV-IPA  (and general) Deflators 86-98 */
/*                     4: FGV-DI   (and general) Deflators 86-98 */
/* All deflator types will be created in loops */
/* Note:  */

local forpidx 2
/* Choice 1: Foreign machinery deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign machinery deflators based on World PPI, WPI, CPI series * USD exchange rate */
local fdfl = `forpidx'

capture program drop rebase90
program define rebase90
    args yr
    while `yr'<=98 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    local yr=`yr'+1
    }
    quietly replace jan90=100
end


/* Foreign price matrix: USDEXCH * PIDX */
/*--------------------------------------*/
if `forpidx' == 1 { use "brazprod/deflate/foreign-ppi", clear 
                    keep if series=="oecd*usdex"
                    drop series
                    }
if `forpidx' == 2 { use "brazprod/deflate/foreign-mix", clear 
                    keep if series=="world*usdex"
                    drop series
                    }
save `forppi'


/* Create Temp. Capital Formation Vectors */
/*----------------------------------------*/
/* Niv80 x Capital Formation Vector (for all industries), 90-98 */
local yr 90
while `yr'<=98 {
insheet using "brazprod/deflate/contas-nacionais/cap-form-`yr'.csv", clear
drop if nivel80==.
rename nivel80 niv80
rename capitalf capform
label var capform "Capital Formation"
sort niv80
drop if niv80==9999
save `capf`yr'', replace
if `yr'==98 {save `capf99', replace}
local yr=`yr'+1
}
/* Make vectors 1986-1989 from 1985 and 1990 */
/* Method: W85 + (DIFF/5)*Step = W90 */
insheet using "brazprod/deflate/contas-nacionais/cap-form-85.csv", clear
drop if nivel80==9999
drop if nivel80==.
rename nivel80 niv80
rename capital start
sort niv80
merge niv80 using `capf90'
drop _merge
    quietly egen tot=sum(capform)
    replace capform=capform/tot
    drop tot
    quietly egen tot=sum(start)
    replace start=start/tot
    drop tot
local step 1
while `step'<=4 { 
gen new=start+`step'*((capform-start)/5)
preserve
    local yr=`step'+85
    keep niv80 new
    rename new capform
    label var capform "Share in Capital Formation"
    sort niv80
    save `capf`yr'', replace
restore
drop new
local step=`step'+1
}


/* Tariff series */
/*---------------*/

use "brazprod/addl/tariffs-cap-monthly", clear
* save "brazprod/addl/trfcapmo", replace
* clear
* matload trfcapmo, path("brazprod/addl") rowname(captype) overwrite
rename captype _rowname
local j 1
while `j' <= _N {
  local rownm`j'=_rowname[`j']
  local j = `j'+1
  }
drop _rowname
mkmat _all, matrix(trfcapmo)
local j = 1
while `j' <= _N {
  matname trfcapmo `rownm`j'', rows(`j') explicit
  local j = `j'+1
  }
local cnam : colfullnames trfcapmo
tokenize "`cnam'"
local j 1
while `j' <= colsof(trfcapmo) {
  local `j'=subinword("``j''","__cons","_cons",1)
  local `j'=subinword("``j''","__b","_b",1)
  local `j'=subinword("``j''","__coef","_coef",1)
  matname trfcapmo ``j'' , columns(`j') explicit
  local j=`j'+1
}


/* Marc's Investment Deflators */
/*-----------------------------*/

/* Domestic & Foreign Investment Deflators */
/* Niv80 x Deflators Matrix */
local choice 1
while `choice'<=5 {
use "brazprod/filters/niv10080", clear
sort niv100
merge niv100 using "brazprod/deflate/comp-defl"   /* Read-in indtype */
keep niv80 niv100 nivmap indtype
sort niv100
if `choice'==1 {merge niv100 using "brazprod/deflate/output-defl-mesq"
                local lstyr=98}
if `choice'==2 {merge niv100 using "brazprod/deflate/output-defl-pim"
                local lstyr=99}
if `choice'==3 {merge niv100 using "brazprod/deflate/output-defl-ipa"
                drop if niv100==1010 | niv100==1020  /* Make computers 1030 */
                local lstyr=99}
if `choice'==4 {merge niv100 using "brazprod/deflate/output-defl-di"
                local lstyr=99}
if `choice'==5 {merge niv100 using "`forppi'"
                local lstyr=98}
keep if _merge==3  /* Keep Only if Deflator for Sector Exists */
drop _merge
keep if jan90~=.
keep niv100 nivmap jan86-dec`lstyr'
sort niv100 nivmap
quietly by niv100 nivmap: keep if _n==1
local yr 86
while `yr'<=`lstyr' {
    quietly egen mjan`yr'=mean(jan`yr'), by(nivmap)
    quietly egen mfeb`yr'=mean(feb`yr'), by(nivmap)
    quietly egen mmar`yr'=mean(mar`yr'), by(nivmap)
    quietly egen mapr`yr'=mean(apr`yr'), by(nivmap)
    quietly egen mmay`yr'=mean(may`yr'), by(nivmap)
    quietly egen mjun`yr'=mean(jun`yr'), by(nivmap)
    quietly egen mjul`yr'=mean(jul`yr'), by(nivmap)
    quietly egen maug`yr'=mean(aug`yr'), by(nivmap)
    quietly egen msep`yr'=mean(sep`yr'), by(nivmap)
    quietly egen moct`yr'=mean(oct`yr'), by(nivmap)
    quietly egen mnov`yr'=mean(nov`yr'), by(nivmap)
    quietly egen mdec`yr'=mean(dec`yr'), by(nivmap)
    drop jan`yr'-dec`yr'
    rename mjan`yr' jan`yr'
    rename mfeb`yr' feb`yr'
    rename mmar`yr' mar`yr'
    rename mapr`yr' apr`yr'
    rename mmay`yr' may`yr'
    rename mjun`yr' jun`yr'
    rename mjul`yr' jul`yr'
    rename maug`yr' aug`yr'
    rename msep`yr' sep`yr'
    rename moct`yr' oct`yr'
    rename mnov`yr' nov`yr'
    rename mdec`yr' dec`yr'
    local yr=`yr'+1
}
sort nivmap 
quietly by nivmap: keep if _n==1
drop niv100
preserve
   use "brazprod/filters/niv10080", clear
   drop niv100 
   sort niv80
   quietly by niv80: keep if _n==1
   sort nivmap
   save `tmp7', replace
restore
joinby nivmap using `tmp7'
drop nivmap
order niv80 jan86-dec`lstyr'
sort niv80
if `choice'==1 {drop jan86-dec89}
save `master', replace


/* Merge data & create capital formation deflators */
local round 1
/* Round 1: Total, 2: Machinery, 3: Vehicles, 4: Computers, 5: Other */
while `round'<=5 {
local yr 86
if `choice'==1 {local yr 90}
while `yr'<=`lstyr' {
use `capf`yr'', clear
if `round'==2 {replace capform=0 if (niv80~=801 & niv80~=1101)}  /* Machinery */
if `round'==3 {replace capform=0 if (niv80~=802 & niv80~=1201 & niv80~=1301)}  /* Vehicles */
if `round'==4 {replace capform=0 if (niv80~=1001)}  /* Computers */
if `round'==5 {replace capform=0 if (niv80~=1401 & niv80~=3201)}  /* Other */
sort niv80
merge niv80 using `master'
keep if _merge==3
drop _merge
    quietly egen tot=sum(capform)
    replace capform=capform/tot
    drop tot
gen nwjan`yr'=jan`yr'*capform
gen nwfeb`yr'=feb`yr'*capform
gen nwmar`yr'=mar`yr'*capform
gen nwapr`yr'=apr`yr'*capform
gen nwmay`yr'=may`yr'*capform
gen nwjun`yr'=jun`yr'*capform
gen nwjul`yr'=jul`yr'*capform
gen nwaug`yr'=aug`yr'*capform
gen nwsep`yr'=sep`yr'*capform
gen nwoct`yr'=oct`yr'*capform
gen nwnov`yr'=nov`yr'*capform
gen nwdec`yr'=dec`yr'*capform
drop jan`yr'-dec`yr'
egen jan`yr'=sum(nwjan`yr')
egen feb`yr'=sum(nwfeb`yr')
egen mar`yr'=sum(nwmar`yr')
egen apr`yr'=sum(nwapr`yr')
egen may`yr'=sum(nwmay`yr')
egen jun`yr'=sum(nwjun`yr')
egen jul`yr'=sum(nwjul`yr')
egen aug`yr'=sum(nwaug`yr')
egen sep`yr'=sum(nwsep`yr')
egen oct`yr'=sum(nwoct`yr')
egen nov`yr'=sum(nwnov`yr')
egen dec`yr'=sum(nwdec`yr')
keep niv80 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
format niv80 %4.0f
label var niv80 "NIVEL 80"
label var jan`yr' "Jan-`yr'"
label var feb`yr' "Feb-`yr'"
label var mar`yr' "Mar-`yr'"
label var apr`yr' "Apr-`yr'"
label var may`yr' "May-`yr'"
label var jun`yr' "Jun-`yr'"
label var jul`yr' "Jul-`yr'"
label var aug`yr' "Aug-`yr'"
label var sep`yr' "Sep-`yr'"
label var oct`yr' "Oct-`yr'"
label var nov`yr' "Nov-`yr'"
label var dec`yr' "Dec-`yr'"
format jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' %10.0g  
drop niv80
keep if _n==1
if `round'==1 {gen str9 captype="total"}
if `round'==2 {gen str9 captype="machinery"}
if `round'==3 {gen str9 captype="vehicles"}
if `round'==4 {gen str9 captype="computers"}
if `round'==5 {gen str9 captype="other"}
if `choice'==5 {
  local mo = 0
  foreach var in jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' {
    local mo = `mo' + 1
    local col = `mo' + (`yr'-86)*12
    replace `var' = `var' * (1+trfcapmo[`round',`col'])
    }
  }
label var captype "Type of Capital"
order captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
save `c`yr'', replace
local yr=`yr'+1
}
if `choice'~=1 {
    use `c86', replace
    local yr 87
}
 else {
    use `c90', replace
    local yr 91
    }
while `yr'<=`lstyr'  {
    merge using `c`yr''
    drop _merge
    local yr=`yr'+1
}
save `cap`round'', replace
local round=`round'+1
}
use `cap1', clear
append using `cap2'
append using `cap3'
append using `cap4'
append using `cap5'
sort captype
gen byte _srtno = 1 if captype=="total"
replace  _srtno = 2 if captype=="machinery"
replace  _srtno = 3 if captype=="vehicles"
replace  _srtno = 4 if captype=="computers"
replace  _srtno = 5 if captype=="other"
sort _srtno
drop _srtno
if `choice'==1 {save "brazprod/deflate/capform-defl-mesq", replace}
if `choice'==2 {save "brazprod/deflate/capform-defl-pim", replace}
if `choice'==3 {save "brazprod/deflate/capform-defl-ipa", replace}
if `choice'==4 {save "brazprod/deflate/capform-defl-di", replace}
if `choice'==5 {
    rebase90 86    
    save "brazprod/deflate/capform-defl-forppi`fdfl'", replace
    }
local choice=`choice'+1
}

matrix drop trfcapmo
