version 7.0
tempfile fdi95 fdi00


/* Prepare FDI sector definitions */
/*--------------------------------*/
foreach perd in "80-95" "95-00" {
insheet using "brazprod\addl\fdi\fdi`perd'.csv", clear
if "`perd'"=="95-00" {
    rename v2 niv50
    replace v3 = "1995" in 1
    local i 3
    while `i'<=14 {
        local varnam = v`i'[1]
        local varnam1 = "dec"+"`varnam'"
        rename v`i' `varnam1'
        local i=`i'+1
        local varnam2 = "perc"+"`varnam'"
        rename v`i' `varnam2'
        local i =`i'+1
    }
}
drop if niv50=="" | niv50=="1" | niv50=="2" | niv50=="3" | niv50=="2,3" | niv50=="9"
drop if substr(niv50,1,2)=="32"       /* In 80-95, 17,21 drops out. In 95-00, 14 drops out. */
drop if niv50=="21" | niv50=="17" | niv50=="14"
drop if niv50=="18"                   /* Cannot be made compatible */
drop if niv50=="21,16" | niv50=="16"  /* Since 21 and 16 are lumped in 95-00, we need to drop 16, too */
replace niv50="z2" if niv50=="7,8"
replace niv50="z2" if niv50=="7" | niv50=="8"
    /* Former applies to 80-95, latter to 95-00 */
replace niv50="z3" if niv50=="10,11"
replace niv50="z3" if niv50=="10" | niv50=="11"
    /* Former applies to 80-95, latter to 95-00 */
replace niv50="z5" if niv50=="24,23"
replace niv50="z5" if niv50=="23" | niv50=="24"
    /* Former applies to 80-95, latter to 95-00 */
replace niv50="z6" if niv50=="31-1,30,29,28,27,26-1,25" | niv50=="31-2" | niv50=="26-2"
replace niv50="z6" if niv50=="31,30,29,28,27,26-1,25" | niv50=="26-2"
    /* Former applies to 80-95, latter to 95-00 */
replace niv50="z4" if niv50=="20,19"
replace niv50="z4" if niv50=="19" | niv50=="20"
    /* Former applies to 95-00, latter to 80-95 */
replace niv50="z1" if niv50=="6,5"
replace niv50="z1" if niv50=="6" | niv50=="5"
    /* Former applies to 95-00, latter to 80-95 */
local yr = substr("`perd'",-2,2)
rename v1 v`yr'
sort niv50
save `fdi`yr''
}
local z1="05,06"
local z2="07,08"
local z3="10,11"
local z4="19,20"
local z5="23,24"
local z6="25,26,27,28,29,30,31"
local rest="09,14,16,17,18,21,32"


/* Prepare 1980-1994 */
/*-------------------*/
use `fdi95', clear
drop jun95
foreach yr in 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 {
    local typ : type dez`yr'
    if substr("`typ'",1,3)=="str" {
        gen long _d`yr'=real(dez`yr')
        drop dez`yr'
        rename _d`yr' dez`yr'
    }
}
order v* niv50 dez1980 dez1981 dez1982 dez1983 dez1984 dez1985 dez1986 dez1987 dez1988 dez1989 dez1990 dez1991 dez1992 dez1993 dez1994
gen long flw1980=.
foreach yr in 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 {
    local prev=`yr'-1
    gen flw`yr'=dez`yr'-dez`prev'
}
sort niv50
by niv50: gen byte _mark=_n
quietly summ _mark
local max=r(max)
gen str80 v95c=v95
local i 1
while `i'<=`max'-1 {
    replace v95c=v95c+", "+v95[_n+1] if _mark==`i' & _mark[_n+1]==`i'+1
    replace v95c=v95c[_n-1] if _mark==`i'+1 & _mark[_n-1]==`i'
    local i=`i'+1
}
drop _*
foreach yr in 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 {
    egen _f`yr'=sum(flw`yr'), by(niv50)
    egen _s`yr'=sum(dez`yr'), by(niv50)
    drop flw`yr' dez`yr'
    rename _f`yr' flw`yr'
    rename _s`yr' stk`yr'
    label var flw`yr' "FDI flow `yr'"
    label var stk`yr' "FDI stock dec `yr'"
}
sort niv50
by niv50: keep if _n==_N
drop flw1980 v95
order niv50 v95c
label var niv50 "Sector Definition (base: Niv50)"
label var v95c "Sector Description"
sort niv50
save `fdi95', replace

/* Prepare 1995-2000 */
/*-------------------*/
use `fdi00', clear
drop perc*
drop if niv50=="Niv50"
sort niv50
foreach yr in 1995 1996 1997 1998 1999 2000 {
    local typ : type dec`yr'
    if substr("`typ'",1,3)=="str" {
        gen _d`yr'=real(dec`yr')
        drop dec`yr'
        rename _d`yr' dec`yr'
    }
    replace dec`yr'=dec`yr'*1000
}
rename dec1995 stk1995
order v00 niv50 stk1995
local yr 1996
while `yr'<=2000 {
    rename dec`yr' flw`yr'
    local prev=`yr'-1
    gen stk`yr'=stk`prev'+flw`yr'
    local yr=`yr'+1
}
sort niv50
by niv50: gen byte _mark=_n
quietly summ _mark
local max=r(max)
gen str80 v00c=v00
local i 1
while `i'<=`max'-1 {
    replace v00c=v00c+", "+v00[_n+1] if _mark==`i' & _mark[_n+1]==`i'+1
    replace v00c=v00c[_n-1] if _mark==`i'+1 & _mark[_n-1]==`i'
    local i=`i'+1
}
drop _*
gen flw1995=.
foreach yr in 1995 1996 1997 1998 1999 2000 {
    egen _f`yr'=sum(flw`yr'), by(niv50)
    egen _s`yr'=sum(stk`yr'), by(niv50)
    drop flw`yr' stk`yr'
    rename _f`yr' flw`yr'
    rename _s`yr' stk`yr'
    label var flw`yr' "FDI flow `yr'"
    label var stk`yr' "FDI stock dec `yr'"
}
sort niv50
by niv50: keep if _n==_N
drop flw1995 v00
order niv50 v00c
label var niv50 "Sector Definition (base: Niv50)"
label var v00c "Sector Description"
sort niv50
save `fdi00', replace


/* Merge datasets, and make them consistent */
/*------------------------------------------*/
use `fdi95', clear
merge niv50 using `fdi00'
drop _merge
order niv50 v95c v00c
gen stk1994n=stk1995-(flw1993+flw1994+flw1996)/3 in 1
local flw1995=(flw1993[1]+flw1994[1]+flw1996[1])/3
local stk94n=int(stk1994n[1]/1000+.5)
local stk94o=int(stk1994[1]/1000+.5)
replace stk1994=(`stk94n'/`stk94o')*stk1994
drop stk1994n
local yr 1993
while `yr'>=1980 {
    local next=`yr'+1
    replace stk`yr'=stk`next'/(1+(flw`next'/stk`yr'))
    replace flw`next'=stk`next'-stk`yr'
    local yr=`yr'-1
}
gen flw1995=stk1995-stk1994
replace niv50="04" if niv50=="4"
gen str21 niv50det="`z1'" if niv50=="z1"
replace   niv50det="`z2'" if niv50=="z2"
replace   niv50det="`z3'" if niv50=="z3"
replace   niv50det="`z4'" if niv50=="z4"
replace   niv50det="`z5'" if niv50=="z5"
replace   niv50det="`z6'" if niv50=="z6"
label var niv50det "Sector Definition, Niv50 details"
gen str2 _niv=niv50
drop niv50
rename _niv niv50
label var niv50 "Sector Definition (base: Niv50)"
order niv50 niv50det
rename v95c v95
rename v00c v00
sort niv50
/* Calculate value for rest of sectors */
replace niv50det="99" if niv50=="0"
expand 2 if niv50det=="99"
sort niv50det niv50
replace niv50det="98" if niv50det=="99" & _n~=_N
egen _d1980=sum(stk1980) if niv50~="0"
quietly summ _d1980, meanonly
replace _d1980=r(mean)
replace stk1980=stk1980-_d1980 if niv50det=="98"
drop _*
local yr 1981
quietly while `yr'<=2000 {
    egen _ds`yr'=sum(stk`yr') if niv50~="0"
    quietly summ _ds`yr', meanonly
    replace _ds`yr'=r(mean)
    replace stk`yr'=stk`yr'-_ds`yr' if niv50det=="98"
    egen _df`yr'=sum(flw`yr') if niv50~="0"
    quietly summ _df`yr', meanonly
    replace _df`yr'=r(mean)
    replace flw`yr'=flw`yr'-_df`yr' if niv50det=="98"
    drop _*
    local yr=`yr'+1
}
/* Make all figures Mio current US$ (rounded to 1,000 US$) */
replace stk1980=stk1980/1000
replace stk1980=int(stk1980*10+.5)/10
label var stk1980 "FDI stock dec 1980"
local yr 1981
while `yr'<=2000 {
    gen _f`yr'=flw`yr'/1000
    gen _s`yr'=stk`yr'/1000
    drop flw`yr' stk`yr'
    rename _f`yr' flw`yr'
    rename _s`yr' stk`yr'
    replace flw`yr'=int(flw`yr'*10+.5)/10
    replace stk`yr'=int(stk`yr'*10+.5)/10
    label var flw`yr' "FDI flow `yr'"
    label var stk`yr' "FDI stock dec `yr'"
    local yr=`yr'+1
}
replace niv50="z9" if niv50det=="98"
replace v95=v95+" - Outros Setores" if niv50det=="98"
replace v00=v00+" - Outros setores" if niv50det=="98"
replace niv50="" if niv50=="0"
replace niv50det="`rest'" if niv50det=="98"
replace niv50det="total" if niv50det=="99"
save "brazprod\addl\fdi", replace
outsheet using "brazprod\addl\fdi.csv", comma replace


/* Prepare FDI series for own use */
/*--------------------------------*/
use "brazprod\addl\fdi", clear
replace niv50det="99" if niv50det=="total"
drop v*
replace niv50det=niv50 if niv50det==""
gen _nexp=(length(niv50det)-2)/3 +1
quietly summ _nexp
local max=r(max)
local i 2
while `i'<=`max' {
    expand `i' if _nexp==`i'
    local i=`i'+1
}
drop _*
sort niv50
by niv50: gen byte _cnt=_n
quietly summ _cnt
local max=r(max)
gen _pos=3*(_cnt-1)+1
local i 1
while `i'<=`max' {
    replace niv50det=substr(niv50det,_pos,2) if _cnt==`i'
    local i=`i'+1
}
sort niv50det
drop niv50
gen byte niv50=int(real(niv50det)) if niv50det~="99"
replace niv50det="total" if niv50det=="99"
drop _* niv50det
drop if niv50==.
drop if niv50==32
order niv50
reshape long stk flw, i(niv50) j(year)
drop if year<1986 | year>1998
replace year=year-1900
rename stk fdistk
rename flw fdiflw
label var niv50 "Sector (Niv50)" 
label var year "Calendar Year"
replace fdistk = fdistk/1000
replace fdiflw = fdiflw/1000
label var fdistk "FDI Stock (Billion US$)"
label var fdiflw "FDI Flow (Billion US$)"
drop if year==91
sort niv50 year
save "brazprod\addl\fdi-use", replace

local flw1995=int(`flw1995'/10000+.5)/100
local stk94o=`stk94o'/1000
local stk94n=`stk94n'/1000
di
disp in green "Inferred FDI flow 1995: " in yellow "`flw1995'" in green " Mio US$"
disp
disp in green "Effect of correction procedure:"
di
disp in green "Old FDI stock 1994: " in yellow "`stk94o'" in green " Mio US$"
disp in green "New FDI stock 1994: " in yellow "`stk94n'" in green " Mio US$"
