version 6.0
tempfile gendefl tmp1 tmp2 tmp3 irate

local type "ipa-og"  /* Used for Real Exchange Rate */
/* Type of R$ Deflator: "igp-di", "inpc", "inpc-real", 
                        "ipa-indtot", "ipa-og", "ipa-transf"
                        see "brazprod\deflate\general-defl.dta" */


/* Prepare Nominal Annual Interest Rate */
/*--------------------------------------*/
insheet using "brazprod\addl\interest\andima\poupanca-use.csv", clear
gen int year=real(substr(data,5,2))+1900
replace year=year+100 if year<1950
egen byte month=fill(1(1)12 1(1)12)
replace month=month+9
replace month=month-12 if month>12
gen date=ym(year,month)
format date %tm
drop year month data
order date valor
gen irate=valor/100
gen ifactor=1+irate
sort date
drop if date<ym(1968,12)
gen icum=ifactor[2] in 2
replace icum=icum[_n-1]*ifactor if _n>2
replace icum=1 in 1
sort date
gen iannual=.
local yr 1969
while `yr' <= 2000 {
    quietly replace iannual=(icum/icum[_n-12])-1 if date==ym(`yr',12)
    local yr = `yr'+1
}
sort date
save `irate', replace


/* Prepare Annual Inflation Rates */
/*--------------------------------*/

/* INPC */
insheet using "brazprod\deflate\ibge\inpc-79-mtb-64.csv", clear
local factor=igpmtb[183]/inpc[183]
replace inpc=`factor'*inpc
replace inpc=igpmtb if inpc==.
drop igpmtb
rename inpc inpcigpc
gen int year=real(substr(data,5,2))+1900
replace year=year+100 if year<1950
egen byte month=fill(1(1)12 1(1)12)
gen date=ym(year,month)
drop month year data
rename date month
format month %tm
order month inpcigpc
expand 25 if _n==1
sort month
replace month=23+_n if _n<25
rename month date
sort date
save `tmp1', replace

/* IGP-DI */
insheet using "brazprod\deflate\fgv\igpdi-44.csv", clear
drop v3
rename v1 data
drop if real(substr(data,5,2))<=61 & real(substr(data,5,2))>50 | data==""
gen int year=real(substr(data,5,2))+1900
replace year=year+100 if year<1950
egen byte month=fill(1(1)12 1(1)12)
gen date=ym(year,month)
format date %tm
drop month year data
order date
sort date
save `tmp2', replace

/* IPA-DI */
insheet using "brazprod\deflate\fgv\ipadi-69.csv", clear
rename v1 data
drop if real(substr(data,5,2))<=61 & real(substr(data,5,2))>50 | data==""
keep data ipadi
gen int year=real(substr(data,5,2))+1900
replace year=year+100 if year<1950
egen byte month=fill(1(1)12 1(1)12)
gen date=ym(year,month)
format date %tm
drop month year data
rename date month
order month
expand 85 if _n==1  /* Add 1962 */
sort month
replace month=23+_n if _n<85
keep month ipadi
/* Error Correction */
capture program drop errdi
program define errdi
   args varname
   replace `varname'=`varname'/1000000000000000000 if `varname'>100000000000000000
end
errdi ipadi
rename month date
sort date
save `tmp3', replace

use `irate', clear
local i 1
while `i'<=3 {
sort date
merge date using `tmp`i'', nokeep
drop _merge
local i = `i'+1
}

gen inpcannu=.
gen igpdannu=.
gen ipadannu=.
local yr 1969
while `yr' <= 2000 {
    quietly replace inpcannu=(inpcigpc/inpcigpc[_n-12])-1 if date==ym(`yr',12)
    quietly replace igpdannu=(igpdi   /igpdi[_n-12])   -1 if date==ym(`yr',12)
    quietly replace ipadannu=(ipadi   /ipadi[_n-12])   -1 if date==ym(`yr',12)
    local yr = `yr'+1
}

gen inpcrate=.
gen igpdrate=.
gen ipadrate=.
local i=_N
while `i'>=1 {
local past=`i'-1
quietly replace inpcrate=(inpcigpc[`i']/inpcigpc[`past'])-1    in `i'
quietly replace igpdrate=(igpdi[`i']/igpdi[`past'])-1          in `i'
quietly replace ipadrate=(ipadi[`i']/ipadi[`past'])-1          in `i'
local i = `i'-1
}

replace inpcigpc=inpcigpc/inpcigpc[1] if _n>1
replace igpdi=igpdi/igpdi[1]          if _n>1
replace ipadi=ipadi/ipadi[1]          if _n>1
rename inpcigpc inpccum
rename igpdi igpdicum
rename ipadi ipadicum

drop if date<ym(1969,1)
drop valor
sort date
order date irate ifactor icum iannual inpcrate inpccum inpcannu igpdrate igpdicum igpdannu ipadrate ipadicum ipadannu

label var date      "Month"
label var irate     "Nominal Interest Rate (Poupanca)"
label var ifactor   "Nominal Interest Factor (Poup.)"
label var icum      "Nomimal Cumul. Interest (Poup.)"
label var iannual   "Annual Nominal Interest (Poup.)"  
label var inpcrate  "Inflation Rate: INPC"
label var inpccum   "Price Index (Cum. Infl.): INPC"
label var inpcannu  "Annual Inflation Rate: INPC"
label var igpdrate  "Inflation Rate: IGP-DI"
label var igpdicum  "Price Index (Cum. Infl.): IGP-DI"
label var igpdannu  "Annual Inflation Rate: IGP-DI"
label var ipadrate  "Inflation Rate: IPA-DI"
label var ipadicum  "Price Index (Cum. Infl.): IPA-DI"
label var ipadannu  "Inflation Rate: IPA-DI"

save "brazprod\addl\interest", replace
