version 6.0
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile master tmp
tempfile inpc86 inpc87 inpc88 inpc89 inpc90 inpc91 inpc92 inpc93 inpc94 inpc95 inpc96 inpc97 inpc98 inpc99
tempfile capf86 capf87 capf88 capf89 capf90 capf91 capf92 capf93 capf94 capf95 capf96 capf97 capf98 capf99

use "brazprod\data\pia-finl", clear
keep if year<=90
keep firm year chmon chyr
sort firm year
merge firm year using "brazprod\data\pia-e\capstruct-86-90"
drop aptotcr apblcr apmasmcr apvehcr apothrcr apcompcr aptotdp apbldp apmasmdp apvehdp apothrdp apcompdp _merge


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general) Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"
/* Type of General Deflator: Used for ground & premises or under choice 9
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod\deflate\general-defl.dta" */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages and rental rates only (see types above) */

local minyr 86  /* Starting year */
local maxyr 90  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */

local corron 3
/* NOTE: In this version, correction not applied to Buildings, Vehicles, and Computers. They behave differently */
/* Corron 1: Correction Factors are Applied */
/*        2: Correction Factors are Not applied */
/*        3: Intermediate: Rebase capital stock before 90 to match 92 */
if `corron'==1 {STOP /* Not available */}

if `choice'==1 {STOP /* Not available */}
if `choice'==2 {STOP /* Not available */}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {
    local ext "gen"
    local saltype="`type'"
    }


/* The output will be "brazprod\data\deflated\pia-cap8690-`ext'-`type'" */
/*----------------------------------------------------------------------*/


/* Transform monetary variables to base "Real" 1995 */
/*--------------------------------------------------*/
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/2.75 if year==93
  replace `varname'=`varname'/(2.75*1000) if (year==92 | year==90 | year==89)
  replace `varname'=`varname'/(2.75*1000000) if (year==88 | year==87 | year==86)
end
/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
nominal apimmo
nominal aptot1
nominal apbl1
nominal apmasum1
nominal apveh1
nominal apother1
nominal apcomp1
nominal aptot0
nominal apbl0
nominal apmasum0
nominal apveh0
nominal apother0
nominal apcomp0
nominal acqtot
nominal acqbl
nominal acqmasum
nominal acqmadom
nominal acqmause
nominal acqmafor
nominal acqveh
nominal acqother
nominal acqcomp
nominal asltot
nominal aslbl
nominal aslmasum
nominal aslveh
nominal aslother
nominal aslcomp
corrneg apimmo
corrneg aptot1
corrneg apbl1
corrneg apmasum1
corrneg apveh1
corrneg apother1
corrneg apcomp1
corrneg aptot0
corrneg apbl0
corrneg apmasum0
corrneg apveh0
corrneg apother0
corrneg apcomp0
corrneg acqtot
corrneg acqbl
corrneg acqmasum
corrneg acqmadom
corrneg acqmause
corrneg acqmafor
corrneg acqveh
corrneg acqother
corrneg acqcomp
corrneg asltot
corrneg aslbl
corrneg aslmasum
corrneg aslveh
corrneg aslother
corrneg aslcomp


/* Redefine & Drop Select Variables */
/*----------------------------------*/
sort firm year
save `master', replace

/* Rebase Deflators to Aug 1994 and Create Temp. Deflator Files */
/*--------------------------------------------------------------*/
capture program drop rebase
program define rebase
    args yr
    while `yr'<=98 {
    quietly replace jan`yr'=(jan`yr'/aug94)
    quietly replace feb`yr'=(feb`yr'/aug94)
    quietly replace mar`yr'=(mar`yr'/aug94)
    quietly replace apr`yr'=(apr`yr'/aug94)
    quietly replace may`yr'=(may`yr'/aug94)
    quietly replace jun`yr'=(jun`yr'/aug94)
    quietly replace jul`yr'=(jul`yr'/aug94)
    if `yr'~=94 {quietly replace aug`yr'=(aug`yr'/aug94)}
    quietly replace sep`yr'=(sep`yr'/aug94)
    quietly replace oct`yr'=(oct`yr'/aug94)
    quietly replace nov`yr'=(nov`yr'/aug94)
    quietly replace dec`yr'=(dec`yr'/aug94)
    local yr=`yr'+1
    }
    quietly replace aug94=1
end

/* Infer applicable December-85 value (using average inflation) */
if "`type'"=="inpc" | "`type'"=="inpc-real" {
            insheet using "brazprod\deflate\ibge\inpc-79-mtb-64.csv", clear
            local decfact = inpc[265]/inpc[264]
            }
if "`type'"=="igp-di" | "`type'"=="ipa-og" {
            insheet using "brazprod\deflate\fgv\igpdi-44.csv", clear
            local decfact = igpdi[505]/igpdi[504]            
            }
if "`type'"=="ipa-indtot" | "`type'"=="ipa-transf" {
            insheet using "brazprod\deflate\fgv\ipadi-69.csv", clear
            local decfact = ipadi[205]/ipadi[204]
            }
            
if `choice'~=9 {
    use "brazprod\deflate\capform-defl-`ext'", clear
    rebase `minyr'
    local yr `minyr'
    preserve
    while `yr'<=98 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        sort captype
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
else {
    use "brazprod\deflate\capform-defl-ipa", clear
    keep captype
        gen str10 defltype="`type'"
        sort defltype
        merge defltype using "brazprod\deflate\general-defl", nokeep
        rebase 86
        drop defltype _merge
        sort captype
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
use "brazprod\deflate\general-defl", clear
rebase 86
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep defltype inddefl jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `inpc`yr'', replace
        local yr=`yr'+1
    }
    restore


/* Deflation Routines */
/*--------------------*/
/* Inflate flow variables to end-of-year values */
capture program drop monthcor
program define monthcor
    args varname yr
    gen byte _marker=1 if jan`yr'~=. & year==`yr'  /* No deflator, no change */
    replace _marker=2 if _marker==1 & (state==3 | state==4)
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==1
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==2 & chmon==12
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr')) if _marker==2 & chmon==11
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr')) if _marker==2 & chmon==10
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr')) if _marker==2 & chmon==9
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr')) if _marker==2 & chmon==8
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr')) if _marker==2 & chmon==7
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr')) if _marker==2 & chmon==6
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr')) if _marker==2 & chmon==5
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr')) if _marker==2 & chmon==4
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr')) if _marker==2 & chmon==3
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr')) if _marker==2 & chmon==2
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr')) if _marker==2 & chmon==1
    drop _marker
end
/* Deflate all flow variables to Aug-94 values */
capture program drop deflate
program define deflate
    args varname yr
    replace `varname'=`varname'/dec`yr' if dec`yr'~=. & year==`yr'
end

if `corron'==3 {
    if `choice'~=9 {use "brazprod\deflate\capcorr-`ext'.dta", clear}
        else       {use "brazprod\deflate\capcorr-`type'.dta", clear}
    local cortot1= totalas[6]/( totalas[1]+ totalas[2]+ totalas[3])*3-1
    local corbld1=buildgas[6]/(buildgas[1]+buildgas[2]+buildgas[3])*3-1
    local cormac1=machinas[6]/(machinas[1]+machinas[2]+machinas[3])*3-1
    local corveh1=vehiclas[6]/(vehiclas[1]+vehiclas[2]+vehiclas[3])*3-1
    local corcom1=computas[6]/(computas[1]+computas[2]+computas[3])*3-1
    local coroth1= otheras[6]/( otheras[1]+ otheras[2]+ otheras[3])*3-1
    local cortot2= totalsl[6]/( totalsl[1]+ totalsl[2]+ totalsl[3])*3-1
    local corbld2=buildgsl[6]/(buildgsl[1]+buildgsl[2]+buildgsl[3])*3-1
    local cormac2=machinsl[6]/(machinsl[1]+machinsl[2]+machinsl[3])*3-1
    local corveh2=vehiclsl[6]/(vehiclsl[1]+vehiclsl[2]+vehiclsl[3])*3-1
    local corcom2=computsl[6]/(computsl[1]+computsl[2]+computsl[3])*3-1
    local coroth2= othersl[6]/( othersl[1]+ othersl[2]+ othersl[3])*3-1
/* Do not apply correction to Buildings, Vehicles, and Computers. They behave differently */
    local corbld1=0
    local corveh1=0
    local corcom1=0
    local coroth1=0
    local corbld2=0
    local corveh2=0
    local corcom2=0
    local coroth2=0
}


use `master', clear


/* Deflate Gross Investment Flows */
/*================================*/

/* PREMISES: INPC types of deflators */
gen str10 defltype="`type'"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort defltype
    merge defltype using `inpc`yr'', nokeep
    replace acqbl=. if (_merge==1 & year==`yr') | jan`yr'==.   /* No deflator, no observation */
    drop inddefl _merge
    if `moncor'==1 {
    monthcor acqbl `yr'
    }
    deflate  acqbl `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqbl=. if year<`minyr'
replace acqbl=. if year>`maxyr'      /* No deflator, no observation */
drop defltype

/* TOTAL: Capital formation deflator "total" */
gen str10 captype="total"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqtot=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqtot `yr'
    }
    deflate  acqtot `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqtot=. if year<`minyr'
replace acqtot=. if year>`maxyr'     /* No deflator, no observation */ 
drop captype

/* OTHER: Capital formation deflator "other" */
gen str10 captype="other"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqother=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqother `yr'
    }
    deflate  acqother `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqother=. if year<`minyr'
replace acqother=. if year>`maxyr'    /* No deflator, no observation */
drop captype

/* MACHINERY: Capital formation deflator "machinery" */
gen str10 captype="machinery"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqmasum=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    replace acqmadom=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace acqmause=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace acqmafor=. if (_merge==1 & year==`yr') | jan`yr'==.    
    drop _merge
    if `moncor'==1 {
    monthcor acqmasum `yr'
    monthcor acqmadom `yr'
    monthcor acqmause `yr'
    monthcor acqmafor `yr'
    }
    deflate  acqmasum `yr'
    deflate  acqmadom `yr'
    deflate  acqmause `yr'
    deflate  acqmafor `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqmasum=. if year<`minyr'   /* No deflator, no observation */
replace acqmasum=. if year>`maxyr'
replace acqmadom=. if year<`minyr'
replace acqmadom=. if year>`maxyr'
replace acqmause=. if year<`minyr'
replace acqmause=. if year>`maxyr'
replace acqmafor=. if year<`minyr'
replace acqmafor=. if year>`maxyr'
drop captype

/* VEHICLES: Capital formation deflator "vehicles"  */
gen str10 captype="vehicles"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqveh=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqveh `yr'
    }
    deflate  acqveh `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqveh=. if year<`minyr'   /* No deflator, no observation */
replace acqveh=. if year>`maxyr'
drop captype

/* COMPUTERS: Capital formation deflator "computers"  */
gen str10 captype="computers"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqcomp=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqcomp `yr'
    }
    deflate  acqcomp `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqcomp=. if year<`minyr'   /* No deflator, no observation */
replace acqcomp=. if year>`maxyr'
drop captype


/* Deflate Capital Stock Variables */
/*=================================*/

/* Correct all stock variables and asset sales for understated inflation */
capture program drop capcorr
program define capcorr
    args varname corname
    replace `varname'=`varname'*`corname'
end
/* Deflate all stock variables and asset sales to Aug-94 values */
capture program drop deflstk
program define deflstk
    args varname yr
    local nextyr=`yr'+1
    replace `varname'=`varname'/((dec`yr'+jan`nextyr')/2) if dec`yr'~=. & year==`yr'
end
capture program drop deflini
program define deflini
    args varname yr decfact
    local prevyr=`yr'-1
    if `yr'~=86 {replace `varname'=`varname'/((dec`prevyr'+jan`yr')/2) if jan`yr'~=. & year==`yr'}
        else    {replace `varname'=`varname'/(jan`yr'*((1+`decfact')/2)) if jan`yr'~=. & year==`yr'}
end

sort firm year

/* Deflate Assets and Liabilities, and Asset Sales */
/*-------------------------------------------------*/

/* Asset Group: TOTAL */
gen str10 captype="total"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    if `prevyr'~=85 {merge captype using `capf`prevyr'', nokeep
                     drop _merge
                     sort captype
                     }
    merge captype using `capf`yr'', nokeep
    replace apimmo=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aptot1=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aptot0=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace asltot=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apimmo  `yr'
    deflstk aptot1  `yr'
    deflini aptot0  `yr' `decfact'
    deflstk asltot  `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop captype

/* Asset Group: BUILDINGS */
gen str10 defltype="`type'"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort defltype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge defltype using `inpc`nextyr'', nokeep
    drop _merge
    sort defltype
    if `prevyr'~=85 {merge defltype using `inpc`prevyr'', nokeep
                     drop _merge
                     sort defltyp
                     }
    merge defltype using `inpc`yr'', nokeep
    replace apbl1=. if (_merge==1 & year==`yr') | dec`yr'==.
    replace apbl0=. if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslbl=. if (_merge==1 & year==`yr') | dec`yr'==.
    drop inddefl _merge
    deflstk apbl1 `yr'
    deflini apbl0 `yr' `decfact'
    deflstk aslbl `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop defltype

/* Asset Group: MACHINERY */
sort year
gen str10 captype="machinery"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    if `prevyr'~=85 {merge captype using `capf`prevyr'', nokeep
                     drop _merge
                     sort captype
                     }
    merge captype using `capf`yr'', nokeep
    replace apmasum1=. if (_merge==1 & year==`yr') | dec`yr'==.
    replace apmasum0=. if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslmasum=. if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apmasum1 `yr'
    deflini apmasum0 `yr' `decfact'
    deflstk aslmasum `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop captype

/* Asset Group: VEHICLES */
gen str10 captype="vehicles"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    if `prevyr'~=85 {merge captype using `capf`prevyr'', nokeep
                     drop _merge
                     sort captype
                     }
    merge captype using `capf`yr'', nokeep
    replace apveh1=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace apveh0=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslveh=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apveh1 `yr'
    deflini apveh0 `yr' `decfact'
    deflstk aslveh `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop captype

/* Asset Group: COMPUTERS */
gen str10 captype="computers"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    if `prevyr'~=85 {merge captype using `capf`prevyr'', nokeep
                     drop _merge
                     sort captype
                     }
    merge captype using `capf`yr'', nokeep
    replace apcomp1=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace apcomp0=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslcomp=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apcomp1 `yr'
    deflini apcomp0 `yr' `decfact'
    deflstk aslcomp `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop captype

/* Asset Group: OTHER */
gen str10 captype="other"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    local prevyr=`yr'-1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    if `prevyr'~=85 {merge captype using `capf`prevyr'', nokeep
                     drop _merge
                     sort captype
                     }
    merge captype using `capf`yr'', nokeep
    replace apother1=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace apother0=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslother=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apother1 `yr'
    deflini apother0 `yr' `decfact'
    deflstk aslother `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    if `yr'~=86 {drop jan`prevyr' feb`prevyr' mar`prevyr' apr`prevyr' may`prevyr' jun`prevyr' jul`prevyr' aug`prevyr' sep`prevyr' oct`prevyr' nov`prevyr' dec`prevyr'}
    local yr=`yr'+1
    }
drop captype

if `corron'==3 {
    egen avgapimm=mean(apimmo  ), by(firm) 
    egen avgapto1=mean(aptot1  ), by(firm) 
    egen avgapbl1=mean(apbl1   ), by(firm) 
    egen avgapma1=mean(apmasum1), by(firm)
    egen avgapve1=mean(apveh1  ), by(firm)
    egen avgapot1=mean(apother1), by(firm)
    egen avgapco1=mean(apcomp1 ), by(firm)
    egen avgapto0=mean(aptot0  ), by(firm) 
    egen avgapbl0=mean(apbl0   ), by(firm) 
    egen avgapma0=mean(apmasum0), by(firm)
    egen avgapve0=mean(apveh0  ), by(firm)
    egen avgapot0=mean(apother0), by(firm)
    egen avgapco0=mean(apcomp0 ), by(firm)
    egen avgaslto=mean(asltot  ), by(firm)    
    egen avgaslbl=mean(aslbl   ), by(firm)
    egen avgaslma=mean(aslmasum), by(firm)
    egen avgaslve=mean(aslveh  ), by(firm)
    egen avgaslot=mean(aslother), by(firm)
    egen avgaslco=mean(aslcomp ), by(firm)
    replace apimmo  =apimmo  +avgapimm*`cortot1'
    replace aptot1  =aptot1  +avgapto1*`cortot1'
    replace apbl1   =apbl1   +avgapbl1*`corbld1'
    replace apmasum1=apmasum1+avgapma1*`cormac1'
    replace apveh1  =apveh1  +avgapve1*`corveh1'
    replace apother1=apother1+avgapot1*`coroth1'
    replace apcomp1 =apcomp1 +avgapco1*`corcom1'
    replace aptot0  =aptot0  +avgapto0*`cortot1'
    replace apbl0   =apbl0   +avgapbl0*`corbld1'
    replace apmasum0=apmasum0+avgapma0*`cormac1'
    replace apveh0  =apveh0  +avgapve0*`corveh1'
    replace apother0=apother0+avgapot0*`coroth1'
    replace apcomp0 =apcomp0 +avgapco0*`corcom1'
    replace asltot  =asltot  +avgaslto*`cortot2'
    replace aslbl   =aslbl   +avgaslbl*`corbld2'
    replace aslmasum=aslmasum+avgaslma*`cormac2'
    replace aslveh  =aslveh  +avgaslve*`corveh2'
    replace aslother=aslother+avgaslot*`coroth2'
    replace aslcomp =aslcomp +avgaslco*`corcom2'
    drop avg*
}

sort firm year
save "brazprod\data\deflated\pia-cap8690-`ext'-`type'-`corron'", replace
