version 6
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile master tmp
tempfile inpdf86 inpdf87 inpdf88 inpdf89 inpdf90 inpdf91 inpdf92 inpdf93 inpdf94 inpdf95 inpdf96 inpdf97 inpdf98
tempfile capf86 capf87 capf88 capf89 capf90 capf91 capf92 capf93 capf94 capf95 capf96 capf97 capf98

use "brazprod/data/pia-finl", clear
keep firm year state change niv100 niv80map state change chmon chyr intmacq acqmasum acqmafor
sort firm year
merge firm year using "brazprod/data/pia-ratios"
keep  firm year state change niv100 niv80map state change chmon chyr intmacq acqmasum acqmafor intfrrat
order firm year state change niv100 niv80map state change chmon chyr intmacq intfrrat acqmasum acqmafor
gen intmacqfor = intfrrat*intmacq
label var intmacqfor "Acquis. of Intm. Goods: Foreign"
* gen intmacqdom = (1-intfrrat)*intmacq
* gen acqmadom   = acqmasum - acqmafor
drop intfrrat acqmasum intmacq
order firm year state change niv100 niv80map state change chmon chyr intmacqfor acqmafor 


/* Choose Settings */
/*-----------------*/

local minyr 86  /* Starting year */
local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */

local forpidx 2
/* Choice 1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
local fdfl = `forpidx'
local ext = "forppi`fdfl'"


/* The output will be "brazprod/data/deflated/pia-foracq-`ext'-`moncor'-`type'" */
/*------------------------------------------------------------------------------------*/


/* Transform monetary variables to base "Real" 1995 */
/*--------------------------------------------------*/
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/2.75 if year==93
  replace `varname'=`varname'/(2.75*1000) if (year==92 | year==90 | year==89)
  replace `varname'=`varname'/(2.75*1000000) if (year==88 | year==87 | year==86)
end
/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
nominal intmacqfor
corrneg intmacqfor
nominal acqmafor
corrneg acqmafor

order firm year state change intmacqfor acqmafor 
sort firm year
compress
save `master', replace


/* Rebase Deflators to Aug 1994 and Create Temp. Deflator Files */
/*--------------------------------------------------------------*/
capture program drop rebase
program define rebase
    args yr
    while `yr'<=98 {
    quietly replace jan`yr'=(jan`yr'/aug94)
    quietly replace feb`yr'=(feb`yr'/aug94)
    quietly replace mar`yr'=(mar`yr'/aug94)
    quietly replace apr`yr'=(apr`yr'/aug94)
    quietly replace may`yr'=(may`yr'/aug94)
    quietly replace jun`yr'=(jun`yr'/aug94)
    quietly replace jul`yr'=(jul`yr'/aug94)
    if `yr'~=94 {quietly replace aug`yr'=(aug`yr'/aug94)}
    quietly replace sep`yr'=(sep`yr'/aug94)
    quietly replace oct`yr'=(oct`yr'/aug94)
    quietly replace nov`yr'=(nov`yr'/aug94)
    quietly replace dec`yr'=(dec`yr'/aug94)
    local yr=`yr'+1
    }
    quietly replace aug94=1
end


/* Deflation Routines */
/*--------------------*/
/* Inflate flow variables to end-of-year values */
capture program drop monthcor
program define monthcor
    args varname yr
    gen byte _marker=1 if jan`yr'~=. & year==`yr'  /* No deflator, no change */
    replace _marker=2 if _marker==1 & (state==3 | state==4)
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==1
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==2 & chmon==12
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr')) if _marker==2 & chmon==11
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr')) if _marker==2 & chmon==10
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr')) if _marker==2 & chmon==9
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr')) if _marker==2 & chmon==8
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr')) if _marker==2 & chmon==7
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr')) if _marker==2 & chmon==6
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr')) if _marker==2 & chmon==5
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr')) if _marker==2 & chmon==4
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr')) if _marker==2 & chmon==3
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr')) if _marker==2 & chmon==2
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr')) if _marker==2 & chmon==1
    drop _marker
end
/* Deflate all flow variables to Aug-94 values */
capture program drop deflate
program define deflate
    args varname yr
    qui replace `varname'=`varname'/dec`yr' if dec`yr'~=. & year==`yr'
end


/* Deflate Foreign Input variables */
/*---------------------------------*/
use "brazprod/deflate/input-defl-forppi`fdfl'", clear
rebase `minyr'
local yr `minyr'
preserve
while `yr'<=98 {
    restore, preserve
    keep ativ80 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    sort ativ80
    save `inpdf`yr'', replace
    local yr=`yr'+1
}
restore
use `master', clear
gen byte ativ80=int(niv80map/100)
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort ativ80
    merge ativ80 using `inpdf`yr'', nokeep
    qui replace intmacqfor=.  if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor intmacqfor `yr'
    }
    deflate  intmacqfor `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
qui replace intmacqfor=. if year<`minyr'    /* No deflator, no observation */
qui replace intmacqfor=. if year>`maxyr'
drop ativ80
save `master', replace


/* Deflate Gross Investment Flows */
/*--------------------------------*/
use "brazprod/deflate/capform-defl-forppi`fdfl'", clear
rebase `minyr'
local yr `minyr'
preserve
while `yr'<=98 {
    restore, preserve
    keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    sort captype
    save `capf`yr'', replace
    local yr=`yr'+1
}
restore
use `master', clear
/* FOREIGN MACHINERY: Capital formation deflator "formachinery" */
gen str9 captype="machinery"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqmafor=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqmafor `yr'
    }
    deflate  acqmafor `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqmafor=. if year<`minyr'   /* No deflator, no observation */
replace acqmafor=. if year>`maxyr'
drop captype


keep firm year intmacqfor  acqmafor
order firm year intmacqfor acqmafor
compress
sort firm year
save "brazprod/data/deflated/pia-foracq-`ext'-`moncor'", replace
