version 7.0
tempfile realex intrst

/* Choose Settings */
/*-----------------*/

local leftout="niv100==101 | niv100==310 | niv100==910 | niv100==1530 | niv100==3210"
/* Leave out the above industries */
/* Note: The following firms are left out in addition "catlife==float(9.1) | catlife==float(9.2) | catlife>=9.3" */

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply INPC to all variables */

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

local type "ipa-indtot"
/* Type of General Deflator: Used for stock variables
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod\deflate\general-defl.dta" 
        except for Cap Stock correction */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages and rental rates only (see types above) */

local corron 3
/* Corron 1: Correction Factors are Applied */
/*        2: Correction Factors are Not applied */
/*        3: Intermediate: Rebase capital stock before 90 to match 92 */
/* NOTE: Computer stock not corrected in this way */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */

if `choice'==1 {
    local ext "mesq"
    local minyr 90
    }
if `choice'==2 {local ext "pim"}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}

* confirm new file "brazprod\use-compl-`ext'`fdfl'.dta"


/* Real Exchange and Interest Rates */
/*----------------------------------*/
    use "brazprod\deflate\realexch", clear
    keep if defltype=="realexch"
    reshape long jan feb mar apr may jun jul aug sep oct nov dec, i(defltype) j(year)
    egen mean=rmean(jan feb mar apr may jun jul aug sep oct nov dec)
    drop jan-dec
    rename mean realexch
    keep year realexch
    label var realexch "Annual Real Exchange Rate (USD)"
    sort year
    save `realex'
    insheet using "brazprod\deflate\ibge\inpc-79-mtb-64.csv", clear
    keep data inpc
    keep if substr(data,1,3)=="Dec"
    drop if int(real(substr(data,5,2)))<85
    sort data
    gen inflrate=inpc/inpc[_n-1]-1
    gen byte year=_n+84
    keep year inflrate
    order year inflrate
    label var inflrate "Annual Inflation Rate (INPC)"
    drop if year==85
    sort year
    save `intrst'

/* Life Categories, and Suspension and Exit Times */
/*------------------------------------------------*/

use "brazprod\data\pia-finl", clear
drop if `leftout'
drop if catlife==float(9.1) | catlife==float(9.2) | catlife>=9.3
keep firm year niv100 sales state change born effborn econborn catlife catentry fstsusyr effextyr lastyr indcor cgcsuc cgcemp firstyr region uf
rename fstsusyr susentr1

/* Note: Exit indicators mark exit time at END of ACTIVE period */
/*       Suspension indicators mark suspension time at BEGINNING of INACTIVE period */

/* Create indicators for exit or suspension in following year */
/* Exit mark: If firm gone at END of year */
sort firm year
gen     _noext=1 if catlife==float(1.1) | catlife==float(1.2) | catlife==float(1.3) | catlife==float(5.5)
replace _noext=1 if catlife==float(3.11) | catlife==float(3.12) | catlife==float(3.13)
replace _noext=1 if catlife==float(5.11) | catlife==float(5.12) | catlife==float(5.13)
replace _noext=1 if catlife==float(5.311) | catlife==float(5.312) | catlife==float(5.313)
sort firm year
gen byte  indexit=1 if year==effextyr & _noext~=1
label var indexit "Indicator: Exiting"

/* Suspension mark: If production suspended at end of year or during part of year (3-3-3 chain possible) */
gen _nosus=1 if catlife==float(1.4)
sort firm year
gen byte indsusp=1 if year==susentr1   & susentr1<effextyr & _nosus~=1 & (sales~=. | sales~=0)
label var indsusp "Indicator: Entering Suspension"
drop _*

/* Search for further periods of suspension */
/* Mark resumption times of production (at least one stop and go per year can be detected) */
/* Mark repeated suspension time at BEGINNING of suspension period */
/* Stop and go is marked with both resumption and suspension in the same year */
gen byte indresum=.
label var indresum "Indicator: Resuming Operation"
local round 1
while `round'>0 {
    local nextrnd=`round'+1
    gen  _dumyr=year if year>susentr`round' & year<effextyr & sales~=. & sales~=0 & state<5
    egen _rtrnyr=min(_dumyr), by(firm)
    gen _helper=1 if year>_rtrnyr & _rtrnyr~=. & year<effextyr & (state==3 | state==5 | (state==8 & change==8 & sales==.) | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.))
    egen _cnt2=count(_helper), by(firm)
    gen byte _helpyr=year if year>_rtrnyr & _rtrnyr~=. & year<effextyr & (state==3 | state==5 | (state==8 & change==8 & sales==.) | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.))
    egen byte susentr`nextrnd'=min(_helpyr), by(firm)
    replace susentr`nextrnd'=. if susentr`nextrnd'<86
    replace indsusp=1 if year==susentr`nextrnd' & susentr`nextrnd'<effextyr & (sales~=. | sales~=0)
    label var susentr`nextrnd' "Indicator: Entering Suspension"
    replace indresum=1 if year==_rtrnyr-1 & year<effextyr
    local round=`round'+1
    egen _check=sum(susentr`nextrnd')
    if _check[_N]==0 {drop susentr`nextrnd'
                      local round=0}
    drop _*
    }
sort firm year

/* Mark years with periods of suspended production (mothballing) */
gen _nomoth=1 if catlife==float(1.4)
gen byte indmoth=1 if _nomoth~=1 & year<effextyr & (state==3 | state==5 | (state==8 & change==8 & sales==.) | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.))
sort firm year
quietly by firm: replace indsusp=1  if indmoth==1 & indresum[_n-1]==1
quietly by firm: replace indresum=1 if indmoth==1 &  indsusp[_n+1]==1
label var indmoth "Indicator: Mothballed"
quietly by firm: replace indmoth=1  if state>=5 & indresum==. & indresum[_n-1]==. & indmoth[_n-1]==1
drop _*

replace indresum=. if state==9
replace indsusp=.  if state==9
replace indmoth=.  if state==9

/* Create own roster of operation categories */
sort firm year
/* 1: Doing well at end of year */ 
quietly by firm: gen byte operat=1 if indmoth~=1 & year<effextyr  
/* 2: Mothballed at end of year */
quietly by firm: replace operat=2 if indmoth==1 | (indresum~=1 & indresum[_n-1]~=1 & indmoth[_n-1]==1 & year<effextyr)    
/* 3: Absorbed   at end of year */
quietly by firm: replace operat=3 if year>=effextyr & indexit~=1
/* 4: Extinct    at end of year */
quietly by firm: replace operat=4 if year>=effextyr & indexit==1
label var operat "State of Operation"
sort firm year
quietly by firm: replace operat=3 if operat[_n-1]==3
quietly by firm: replace operat=4 if operat[_n-1]==4


/* Economic Age of Firm */
/*----------------------*/
gen     _marksuc=1 if catentry==float(2.2) | catentry==float(2.3) | catentry==float(2.4)
replace _marksuc=1 if catentry==float(4.12) | catentry==float(4.13) | catentry==float(4.14)
replace _marksuc=1 if catentry==float(4.22) | catentry==float(4.23) | catentry==float(4.24)
replace _marksuc=1 if catentry==float(4.32) | catentry==float(4.33) | catentry==float(4.34)
replace _marksuc=1 if catentry==float(8.2) | catentry==float(8.3) | catentry==float(8.4)
gen     _birthyr=effborn
replace _birthyr=born if _birthyr==.
replace _birthyr=econborn if econborn~=. & _marksuc==1
replace _birthyr=firstyr+1900 if _birthyr==. & catentr==3
replace _birthyr=firstyr+1900 if catentry==float(9.2)
replace _birthyr=econborn if econborn~=. & _birthyr==.
gen int age=year+1900+1-_birthyr
label var age "Age in years"
drop _*

/* Sector Re-Classification */
gen int _dumsec=niv100 if year==lastyr
egen int _dumspl=max(_dumsec), by(firm)
replace _dumsec=_dumspl
drop _dumspl
local round 1
while `round'<=2 {  /* Two rounds are enough, no more replacements after that */
    sort firm year
    quietly by firm: replace _dumsec=niv100 if year==lastyr-1 & _dumsec[_n+1]==.
    egen int _dumspl=max(_dumsec), by(firm)
    replace _dumsec=_dumspl
    drop _dumspl
    local round=`round'+1
}
replace niv100=_dumsec

keep firm year niv100 region uf operat indexit indsusp indresum indmoth age
sort firm year


/* Load Economic Variables */
/*-------------------------*/

if `choice'~=9  {
    merge firm year using "brazprod\data\pia-capstruct-compl-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'"
    }
if `choice'==9 {
    local ext "gen"
    local saltype "inpc"
    merge firm year using "brazprod\data\pia-capstruct-compl-`ext'`fdfl'-`moncor'-`type'-`corron'"
    }

keep firm year niv100 region uf operat indexit indsusp indresum indmoth age apimmo1 apimmo1x apimmo1r acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x
sort firm year

if `choice'~=9 {
    merge firm year using "brazprod\data\pia-use-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'"
    }
if `choice'==9 {
    local ext "gen"
    local saltype "inpc"
    merge firm year using "brazprod\data\pia-use-gen-`moncor'-`type'-`corron'"
    }
drop if `leftout'
drop if catlife==float(9.1) | catlife==float(9.2) | catlife>=9.3
keep  firm year niv100 region uf operat indexit indsusp indresum indmoth age sales difstock wagebl wagewh labfbl labfwh intmacq* intmdif profit apimmo1 apimmo1x apimmo1r acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x crtot aslsimmo asrtimmo
order firm year niv100 region uf operat indexit indsusp indresum indmoth age sales difstock wagebl wagewh labfbl labfwh intmacq* intmdif profit apimmo1 apimmo1x apimmo1r acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x crtot aslsimmo asrtimmo

sort firm year
merge firm year using "brazprod\data\pia-ratios", nokeep
keep  firm year niv100 region uf operat indexit indsusp indresum indmoth age sales difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x apimmo1r acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x crtot aslsimmo asrtimmo crrat crltrat crforrat
order firm year niv100 region uf operat indexit indsusp indresum indmoth age sales difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x apimmo1r acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x crtot aslsimmo asrtimmo crrat crltrat crforrat

sort firm year
quietly by firm year: keep if _n==1
merge firm year using "brazprod\exp-imp\exp-imp", nokeep
keep  firm year niv100 region uf operat indexp indexit indsusp indresum indmoth age sales exp difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apimmo1r apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x crtot aslsimmo asrtimmo crrat crltrat crforrat
order firm year niv100 region uf operat indexp indexit indsusp indresum indmoth age sales exp difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat
rename exp exports


/* Load Complementary Variables */
/*------------------------------*/

sort niv100
merge niv100 using "brazprod\deflate\comp-defl", nokeep
rename niv80map niv80
keep  firm year niv100 indtype region uf operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat
order firm year niv100 indtype region uf operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat

sort niv100
joinby niv100 using "brazprod\filters\niv10080", unmatched(master)
keep  firm year niv100 niv80 indtype region uf operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat
order firm year niv100 niv80 indtype region uf operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat

sort niv80 year
merge niv80 year using "brazprod\addl\imp-penetrat", nokeep
keep  firm year niv100 niv80 indtype region uf reffpen operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat
order firm year niv100 niv80 indtype region uf reffpen operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat

sort niv80 year
merge niv80 year using "brazprod\addl\tariffs-outp", nokeep
keep  firm year niv100 indtype region uf reffpen tariff tariffrx operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat

sort firm year
rename reffpen _reff
rename tariff _tarf
rename tariffrx _tarfrx
egen reffpen =mean(_reff),   by(firm year)
egen tariff  =mean(_tarf),   by(firm year)
egen tariffrx=mean(_tarfrx), by(firm year)
label var reffpen  "Eff. Penetr. of Sector (Ramos)"
label var tariff   "Annual Tariff (Sector)"
label var tariffrx "Ann. Exch. R. Adj. Tariff (Sec.)"
drop _*

sort firm year
quietly by firm year: gen _mark=1 if _n>=2
drop if _mark==1
drop _mark
order firm year niv100 indtype region uf reffpen tariff tariffrx operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif profit intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r crtot aslsimmo asrtimmo crrat crltrat crforrat

sort year
merge year using `realex', nokeep
drop _merge
sort year
merge year using `intrst', nokeep
drop _merge

sort firm year
order firm year operat indexp indexit indsusp indresum indmoth age sales exports difstock wagebl wagewh labfbl labfwh intmacq intmdif intmacqfor apimmo1 apimmo1x acqtot asltot apimmo0 apimmo0x apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x apmause1 apmaus1x apmause0 apmaus0x apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apimmo1r aslsimmo asrtimmo crrat crltrat crforrat crtot profit niv100 indtype region uf reffpen tariff tariffrx inflrate realexch
iis firm
tis year

capture notes drop _all
note: local leftout0 = "`leftout'"
note: local choice0 = "`choice'"
note: local type0 = "`type'"
note: local saltype0 = "`saltype'"
note: local corron0 = "`corron'"
note: local moncor0 = "`moncor'"

save "brazprod\use-compl-`ext'`fdfl'", replace
