version 7.0
set matsize 180
set logtype text
tempfile ap

/* Choose Settings */
/*-----------------*/

/* Drop sectors */
local sel1 = "niv50==."
/* local sel1 = "niv50==. | niv50==3 | niv50==5 | niv50==6 | niv50==12 | niv50==29 | niv50==30" */
/* Drop mining, keep manufacturing */
local sel2 = "niv50 <= 3"

local yrmax=98

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

* confirm new file "brazprod\use-tfp-`ext'`fdfl'-`outtype'-`trdtype'.dta"


/* Load Data Set */
/*---------------*/

use "brazprod\use-compl-`ext'`fdfl'", clear
keep firm year operat indexit indsusp age sales difstock labfbl labfwh intmacq intmacqfor apimmo1 apimmo0 apimmo1x apimmo0x apimmo1r acqtot asltot apmasum1 apmasm1x acqmasum acqmafor aslmasum apmasum0 apmasm0x apmafor1 apmafr1x apmafor0 apmafr0x profit crrat crltrat crforrat crtot niv100 indtype region uf reffpen-realexch
sort firm year
quietly by firm: gen apimmo0r=apimmo1r[_n-1] if year~=92
egen _dummy=mean(apimmo1r) if year>=89 & year<=92, by(firm)
replace apimmo0r=_dummy if year==92
gen _temp1=-difstock  /* Positive value means decrease in stock */
egen output=rsum(sales _temp1)
gen valadd=output-intmacq
rename intmacq intmed
gen profrat = profit/sales
label var profrat "Profit/Sales"
drop _* sales difstock profit
label var valadd "Value Added"
label var output "Output"
label var intmed "Intermediate Input (Materials)"
replace valadd=. if valadd<0
replace output=. if output<0
replace intmed=. if intmed<0
gen ntinv=acqtot-asltot
label var ntinv "Net Investment"
gen ntkinv=acqmasum-aslmasum
label var ntkinv "Net Machinery Investment"
gen ntqinv=ntinv-ntkinv
label var ntqinv "Net Other (Q) Investment"
drop acqtot asltot acqmasum aslmasum 
egen apim1tot=rsum(apimmo1x apimmo1r)
label var apim1tot "Employed Capital Stock - End Y."
egen apim0tot=rsum(apimmo0x apimmo0r)
label var apim0tot "Employed Capital Stock - Beg. Y."
drop apimmo1 apimmo0 apimmo0x apimmo1x
gen kappa1=apmafr1x/apmasm1x
label var kappa1 "Foreign Machinery Share - End Y."
gen kappa0=apmafr0x/apmasm0x
label var kappa0 "Foreign Machinery Share - Beg Y."
gen mu = intmacqfor/intmed
label var mu "Foreign Intermediates Share"
rename apmasm1x apk1
label var apk1 "Machinery Stock - End Y."
rename apmasm0x apk0
label var apk0 "Machinery Stock - Beg. Y."
gen apq1=apim1tot-apk1
label var apq1 "Other Capital (Q) - End Y."
gen apq0=apim0tot-apk0
label var apq0 "Other Capital (Q) - Beg. Y."
preserve
    keep firm year apk1 apq1
    sort firm year
    compress
    save `ap'
restore
drop apmasum1 apmasum0 apmafor1 apmafr1x apmafor0 apmafr0x apimmo1r apimmo0r
sort firm year
merge firm using "brazprod\cgc-lig\firmhead", nokeep
keep  firm year operat indexit indsusp age valadd output mu intmed labfbl labfwh apim* kappa* apk* apq* ntkinv ntqinv profrat crrat crltrat crforrat crtot niv100 indtype region uf catlife effextyr lastyr reffpen-realexch
order firm year operat indexit indsusp age valadd output mu intmed labfbl labfwh apim* kappa* apk* apq* ntkinv ntqinv profrat crrat crltrat crforrat crtot niv100 indtype region uf catlife effextyr lastyr reffpen-realexch
gen lnvaladd=ln(valadd)
gen lnoutput=ln(output)
gen lnintmed=ln(intmed)
gen lnlabfbl= ln(labfbl)
gen lnlabfwh= ln(labfwh)
gen lnapim1t= ln(apim1tot)
gen lnapim0t= ln(apim0tot)
gen lnapk1  = ln(apk1)
gen lnapk0  = ln(apk0)
gen lnapq1  = ln(apq1)
gen lnapq0  = ln(apq0)
gen lnage   = ln(age)
label var lnvaladd "Log Value Added"
label var lnoutput "Log Output"
label var lnintmed "Log Intm. Input"
label var lnlabfbl "Log Lab. F.: Blue Collar"
label var lnlabfwh "Log Lab. F.: White Collar"
label var lnapim1t "Log Empl. Capital Stock - End Y"
label var lnapim0t "Log Empl. Capital Stock - Beg Y"
label var lnapk1 "Log Machinery Stock - End Y"
label var lnapk0 "Log Machinery Stock - Beg Y"
label var lnapq1 "Log Other Capital Stock - End Y"
label var lnapq0 "Log Other Capital Stock - Beg Y"
label var age    "Economic Age in years"
label var lnage  "Log of Economic Age"
gen byte indsurvv=1 if indexit~=1
replace  indsurvv=0 if indexit==1
label var indsurvv "Indic. 1: Lives Next Year"
drop indexit indsusp
gen byte niv50=int(niv100/100)
label var niv50 "Sector of Firm (NIV50)"
sort firm year
order firm year operat indsurvv age lnage valadd lnvaladd output lnoutput mu intmed lnintmed labfbl labfwh lnlabfbl lnlabfwh nt* apim1tot apim0tot lnapim1t lnapim0t kappa* apk* lnapk* apq* lnapq* profrat crrat crltrat crforrat crtot niv* indtype region uf catlife effextyr lastyr


/* Reduce Data to less Sectors, Create Dummies, Kletgril */
/*-------------------------------------------------------*/
drop if `sel1' 
drop if `sel2'

if $trd==0 | $trd==3 {
    egen kletgril=sum(output), by(niv50 year)
    replace kletgril=log(kletgril*(1+reffpen))
    label var kletgril "Log Agg. Demand for KletGri96"
    }
drop if catlife>=9.3
drop if year>`yrmax'

quietly tabulate year, generate(dyr)
local yr 86
local i 1
while `yr' <= `yrmax' {
   if `yr'==91 {local yr 92}
   rename dyr`i' dyr`yr'
   label var dyr`yr' "Indic. Year 19`yr'"
   local i=`i'+1
   local yr=`yr'+1        
   }

quietly tabulate region, generate(dreg)
replace dreg3=0 if uf==35
label var dreg1 "Indic. Region: North"
label var dreg2 "Indic. Region: NorthEast"
label var dreg3 "Indic. Region: SouthEast, not SP"
label var dreg4 "Indic. Region: South"
label var dreg5 "Indic. Region: CenterWest"
egen _labftot=rsum(labfbl labfwh)
gen byte dlbfmed=1 if _labftot>=30 & _labftot<300
replace  dlbfmed=0 if dlbfmed~=1
label var dlbfmed "Indic. Labor Force >=30"
gen byte dlbfbig=1 if _labftot>=300
replace  dlbfbig=0 if dlbfbig~=1
label var dlbfbig "Indic. Labor Force >=300"
sort firm year
drop _*

gen byte trend1=year-86 if year<91
gen byte trend2=year-86 if year>91 & year<96
gen byte trend3=year-86 if year>=96
replace trend1=0 if trend1==.
replace trend2=0 if trend2==.
replace trend3=0 if trend3==.
label var trend1 "Trend in 1986-1990"
label var trend2 "Trend in 1992-1995"
label var trend3 "Trend in 1996-1998"


/* Prepare Vars for Estimation Coefficients */
/*------------------------------------------*/

gen olsbetbl=.
gen olsbetwh=.
gen olsbetk=.
gen olsbetq=.
gen olskappa=.
gen wibetbl=.
gen wibetwh=.
gen wikappa=.
gen wibetq=.
gen wibetk=.
if $out==2 {gen olsbetintm=.
            gen wibetintm=.
            gen olsmu=.
            gen wimu=.
            }
if $trd==3 {
    gen olsklegr=.
    gen wiklegri=.
    }
if $trd==1 {
    gen olstrd1=.
    gen olstrd2=.
    gen olstrd3=.
    gen witrd1=.
    gen witrd2=.
    gen witrd3=.
    }
label var olsbetbl "OLS Blue-Collar Coeff."
label var olsbetwh "OLS White-Collar Coeff."
label var olsbetk  "OLS Machinery Coeff."
label var olsbetq  "OLS Other Capital Coeff."
label var olskappa "OLS Foreign Mach. Coeff."
label var wibetbl  "Within Blue-Collar Coeff."
label var wibetwh  "Within White-Collar Coeff."
label var wibetk   "Within Machinery Coeff."
label var wibetq   "Within Other Capital Coeff."
label var wikappa  "Within Foreign Mach. Coeff."
if $out==2 {label var olsbetintm "OLS Interm. Coeff."
            label var wibetintm "Within Interm. Coeff."
            label var olsmu "OLS Foreign Interm. Coeff."
            label var wimu  "Within Foreign Intm. Coeff."
            }
if $trd==3 {
    label var olsklegr "OLS Coeff. Agg. Demand"
    label var wiklegri "Within Coeff. Agg. Demand"
    }
if $trd==1 {
    label var olstrd1 "OLS Trend -91 Coeff."
    label var olstrd2 "OLS Trend -95 Coeff."
    label var olstrd3 "OLS Trend -98 Coeff."
    label var witrd1  "Within Trend-91 Coeff."
    label var witrd2  "Within Trend-95 Coeff."
    label var witrd3  "Within Trend-98 Coeff."
    }
gen olssdvbl=.
gen olssdvwh=.
gen olscovlb=.
gen olssdvk=.
gen olssdvq=.
gen olscovk=.
gen olssdvkap=.
gen wisdvbl=.
gen wisdvwh=.
gen wicovlb=.
gen wisdvk=.
gen wisdvq=.
gen wicovk=.
gen wisdvkap=.
if $trd==3 {
    gen olssdvklegr=.
    gen wisdvklegri=.
    }
if $out==2 {gen olssdvintm=.
            gen wisdvintm=.
            gen olssdvmu=.
            gen wisdvmu=.
            gen olscovimwh=.
            gen wicovimwh=.
            gen olscovimbl=.
            gen wicovimbl=.
            }
gen int olsnum=.
gen int winum=.
label var olssdvbl   "OLS Blue-Collar Coeff. Stdev."
label var olssdvwh   "OLS White-Collar Coeff. Stdev."
label var olssdvk    "OLS Machinery Coeff. Stdev."
label var olssdvq    "OLS Other Cap. Coeff. Stdev."
label var olssdvkap  "OLS For. Mach. Coeff. Stdev."
label var olscovlb   "OLS Labor Coeff. Covar."
label var olscovk    "OLS Capital Coeff. Covar."
if $trd==3 {label var olssdvklegr "OLS Agg.Dem. Coeff. Stdv."}
label var wisdvbl  "Within Blue-Collar Coeff. Stdev."
label var wisdvwh  "Within White-Collar Coeff. Stdv."
label var wisdvk   "Within Machinery Coeff. Stdev."
label var wisdvq   "Within Other Cap. Coeff. Stdev."
label var wisdvkap "Within For. Mach. Coeff. Stdev."
label var wicovlb  "Within Labor Coeff. Covar."
label var wicovk   "Within Capital Coeff. Covar."
if $trd==3 {label var wisdvklegri "Within Agg.Dem. Coeff. Stdv."}
if $out==2 {label var olssdvintm "OLS Interm. Coeff. Stdev."
            label var wisdvintm  "Within Interm. Coeff. Stdev."
            label var olssdvmu   "OLS For. Intm. Coeff. Stdev."
            label var wisdvmu    "Within For. Intm. Coeff. Stdev."
            label var olscovimbl "OLS Bl.Col.-Intm. Coeff. Covar"
            label var olscovimwh "OLS Wh.Col.-Intm. Coeff. Covar"
            label var wicovimbl  "Within Bl.Col.-Intm. Coeff. Cov."
            label var wicovimwh  "Within Wh.Col.-Intm. Coeff. Cov."
            }
label var olsnum   "OLS Observations"
label var winum    "Within Observations"
gen betabl=.
gen betawh=.
gen betak=.
gen betaq=.
gen betakappa=.
if $out==2 {gen betaintm=.
            gen betamu=.}
if $trd==3 {gen bklegri=.}
gen betafe=.
if $trd==2 {
    gen byr87=.
    gen byr88=.
    gen byr89=.
    gen byr90=.
    gen byr92=.
    gen byr93=.
    gen byr94=.
    gen byr95=.
    gen byr96=.
    gen byr97=.
    gen byr98=.
    }
if $trd==1 {
    gen btrd1=.
    gen btrd2=.
    gen btrd3=.
    }
gen int obsnum=.
label var betabl "Olley-Pakes Blue-Collar Coeff."
label var betawh "Olley-Pakes White-Collar Coeff."
label var betak  "Olley-Pakes Machinery Coeff."
label var betaq  "Olley-Pakes Other Capital Coeff."
label var betakappa  "Olley-Pakes For. Mach. Coeff."
if $out==2 {label var betaintm "Olley-Pakes Interm. Coeff."
            label var betamu "Olley-Pakes For. Interm. Coeff."
            }
if $trd==3 {label var bklegri "Olley-Pakes Coeff. Agg. Demand"}
label var betafe  "Olley-Pakes Firm Fixed Effect"
if $trd==2 {
    label var byr87 "Olley-Pakes Year Indic. 87"
    label var byr88 "Olley-Pakes Year Indic. 88"
    label var byr89 "Olley-Pakes Year Indic. 89"
    label var byr90 "Olley-Pakes Year Indic. 90"
    label var byr92 "Olley-Pakes Year Indic. 92"
    label var byr93 "Olley-Pakes Year Indic. 93"
    label var byr94 "Olley-Pakes Year Indic. 94"
    label var byr95 "Olley-Pakes Year Indic. 95"
    label var byr96 "Olley-Pakes Year Indic. 96"
    label var byr97 "Olley-Pakes Year Indic. 97"
    label var byr98 "Olley-Pakes Year Indic. 98"
    }
if $trd==1 {
    label var btrd1  "Olley-Pakes Trend -91 Coeff."
    label var btrd2  "Olley-Pakes Trend -95 Coeff."
    label var btrd3  "Olley-Pakes Trend -98 Coeff."
    }
label var obsnum "Olley-Pakes Observations"
gen bsdvbl=.
gen bsdvwh=.
gen bcovlb=.
gen bsdvk=.
gen bsdvq=.
gen bcovk=.
gen bsdvkappa=.
if $trd==3 {gen bsdvklegri=.}
if $out==2 {gen bsdvintm=.
            gen bsdvmu=.
            gen bcovimbl=.
            gen bcovimwh=.}
label var bsdvbl "Olley-Pakes Blue-Colr Coef. Sdv."
label var bsdvwh "Olley-Pakes White-Col Coef. Sdv."
label var bsdvk  "Olley-Pakes Machinery Coef. Sdv."
label var bsdvq  "Olley-Pakes Othr Cap. Coef. Sdv."
label var bcovlb "Olley-Pakes Labor Coef. Covar."
label var bcovk  "Olley-Pakes Capital Coef. Covar."
label var bsdvkappa  "Olley-Pakes For.Mach. Coef. Sdv."
if $trd==3 {label var bsdvklegri "Olley-Pakes Agg.Dem. Coef. Stdv."}
if $out==2 {label var bsdvintm "Olley-Pakes Interm. Coef. Stdev."
            label var bsdvmu   "Olley-Pakes For. Int. Coef. Sdv."
            label var bcovimbl "Olley-Pakes Intm. BlCol. Covar."
            label var bcovimwh "Olley-Pakes Intm. WhCol. Covar."}
gen phihat1=.
gen phihat0=.
gen phatprob=.
gen phatlogt=.
label var phihat0 "Olley-Pakes Phi - Beg Y"
label var phihat1 "Olley-Pakes Phi - End Y"
label var phatprob "Olley-Pakes Survivl Pr. (Probit)"
label var phatlogt "Olley-Pakes Survival Pr. (Logit)"

if $trd==3 {
    keep  firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch kletgril dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* bklegri obsnum phi* phat* dyr*
    order firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch kletgril dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* bklegri obsnum phi* phat* dyr*
    }
if $trd==2 {
    keep  firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* byr8* byr9* obsnum phi* phat* dyr*
    order firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* byr8* byr9* obsnum phi* phat* dyr*
    }
if $trd==1 {
    keep  firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* btrd* obsnum phi* phat*
    order firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* btrd* obsnum phi* phat*
    }
if $trd==0 {
    keep  firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch kletgril dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* obsnum phi* phat*
    order firm year indsurvv lnage lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed profrat crrat crltrat crforrat crtot nt* reffpen-realexch kletgril dyr* dreg* dlbf* trend* niv50 region catlife effextyr lastyr ols* wi* beta* bsdv* bcov* obsnum phi* phat*
}


/* Finalize */
/*----------*/

/* Drop unnecessary variables for current estimation setup */
if $trd~=2 {drop dyr* dreg* dlbf* region catlife effextyr lastyr}
else       {drop dreg* dlbf* region catlife effextyr lastyr} 
drop profrat crrat crltrat crforrat crtot  /* Not of use in survival probability estimation */

/* Prepare cross-equation restriction on kappa and mu */
replace kappa1=0 if year>=96
replace mu=0     if year<=95

save "brazprod\use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", replace


/* Save dummy variables in separate file */
/*---------------------------------------*/

use "brazprod/use-compl-`ext'`fdfl'", clear
keep firm year labfbl labfwh uf
sort firm year
merge firm year using `ap'
keep firm year labfbl labfwh apk1 apq1 uf

/* Calculate dummies */

egen _labftot=rsum(labfbl labfwh)
gen byte dlbfmed=1 if _labftot>=30 & _labftot<300
replace  dlbfmed=0 if dlbfmed~=1
label var dlbfmed "Indic. Labor Force >=30"
gen byte dlbfbig=1 if _labftot>=300
replace  dlbfbig=0 if dlbfbig~=1
label var dlbfbig "Indic. Labor Force >=300"
egen _ap=rsum(apk1 apq1)
egen _lowpctle=pctile(_ap), p(33)
egen _uprpctle=pctile(_ap), p(67)
gen byte dcapmed= (_ap>_lowpctle & _ap<=_uprpctle)
label var dcapmed "Indic. Medium Capital Stock"
gen byte dcapbig= (_ap>_uprpctle)
label var dcapbig "Indic. Large Capital Stock"
drop _*

quietly tabulate uf, generate(duf)
/* quietly tabulate indtype, generate(dsec) */
/* quietly tabulate niv50, generate(dsec) */
/* quietly tabulate niv100, generate(dsec) */
/* quietly tabulate year, generate(dyr) */
/* Note: Year and sector niv100 dummies not feasible since tariffs on niv100 level, and realexch on year level */
/*       As it turns out, not even niv50 is sufficiently rough to remain significant */
/*       Stata even drops the indtype sector dummy */

keep firm year dlbfmed dlbfbig dcapmed dcapbig duf*
sort firm year
compress
save "brazprod/use-tfp-`ext'`fdfl'-dummies", replace
