version 7.0
set matsize 180
set logtype text
capture log close


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}

* confirm new file "tfpest/estimate/logs/compreg-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'.log"
capture mkdir "tfpest/estimate/estmat/mat-comp-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'"

use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
* keep if niv50==3 | niv50==8
* keep if niv50==12
* keep if niv50==8 | niv50==11 | niv50==19
if ~ $xeff {drop reffpen-realexch}
local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"

foreach reg in "ols" "wi" {
  foreach type in b se e r {
    capture matrix drop _`reg'kap_`type'
    capture matrix drop _`reg'mu_`type'
    capture matrix drop `reg'_`type'
    }
}

/* Estimation by Niv50 */
/*---------------------*/

sort firm year

capture matrix drop compreg

capture log close
log using "tfpest/estimate/logs/compreg-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'.log", replace

preserve

local grp 1
while `grp' <= `maxgrp' {

quietly summ niv50 if group==`grp'
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {local nivdsp = "0`recniv'"}
    else         {local nivdsp = "`recniv'"}
disp
disp
disp "Niv50 == `nivdsp'"
disp "-----------"
disp "(Observations: `obs')"
disp

keep if group==`grp'  /* This line can be removed but makes program faster */
    if $trd==3 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 lnage kletgril"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 lnage kletgril"}
        }
    if $trd==2 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 lnage dyr87-dyr98"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 lnage dyr87-dyr98"}
        }
    if $trd==1 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 lnage trend*"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 lnage trend*"}
        }
    if $trd==0 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 lnage"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 lnage"}
        }

/* OLS regression */

ollpak1 "`rvars'" "group==`grp'"
if `grp'==1 {
    est2vec ols, e(N N_g r2 r2_a g_max g_min g_avg r2_w r2_b r2_o F) name(niv`nivdsp')
    test kappa1 = lnapk1
    est2vec _olskap, r(p F chi2 df) name(niv`nivdsp')
    test mu     = lnintm
    est2vec _olsmu, r(p F chi2 df) name(niv`nivdsp')
    }
else {
    est2vec ols,  addto(ols) nokeep name(niv`nivdsp')
    test kappa1 = lnapk1
    est2vec _olskap, raddto(_olskap) nokeep name(niv`nivdsp')
    test mu     = lnintm
    est2vec _olsmu, raddto(_olsmu) nokeep name(niv`nivdsp')
    }


/* FE regression */

ollpak1x "`rvars'" "group==`grp'"
ollpak1x "`rvars'" "group==`grp'"
if `grp'==1 {
    est2vec wi, e(N N_g r2 r2_a g_max g_min g_avg r2_w r2_b r2_o F) name(niv`nivdsp')
    test kappa1 = lnapk1
    est2vec _wikap, r(p F chi2 df) name(niv`nivdsp')
    test mu     = lnintm
    est2vec _wimu, r(p F chi2 df) name(niv`nivdsp')
    }
else {
    est2vec wi,  addto(wi) nokeep name(niv`nivdsp')
    test kappa1 = lnapk1
    est2vec _wikap, raddto(_wikap) nokeep name(niv`nivdsp')
    test mu     = lnintm
    est2vec _wimu, raddto(_wimu) nokeep name(niv`nivdsp')
    }

restore, preserve
local grp =`grp'+1
}

foreach reg in "ols" "wi" {
    matrix rownames _`reg'kap_r = kappa:r(p) kappa:r(F) kappa:r(chi2) kappa:r(df)
    matrix rownames _`reg'mu_r = mu:r(p) mu:r(F) mu:r(chi2) mu:r(df)
    matrix `reg'_r =  _`reg'mu_r \ _`reg'kap_r
    foreach type in b se e r {
        drop _all
        matsave `reg'_`type', path("tfpest/estimate/estmat/mat-comp-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'") replace
    }
  }
restore

foreach reg in "ols" "wi" {
   matrix drop _`reg'kap_r _`reg'mu_r
   foreach type in b se e r {
     matrix drop `reg'_`type'
     }
}

log off
