version 7.0
set matsize 180
set logtype text

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global maxiter=250  /* Maximum number of iterations in mle routines */

confirm new file "tfpest\estimate\logs\olley-pakes-survvprob-`ext'`fdfl'.log"
confirm new file "tfpest\estimate\coeff-survvprob-`ext'`fdfl'.dta"
capture mkdir "tfpest\estimate\estmat\pfct"

use "tfpest\use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
keep firm year niv50 phat* indsurvv reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv 
local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"


/* Estimation by Niv50 */
/*---------------------*/

capture log close
log using "tfpest\estimate\logs\olley-pakes-survvprob-`ext'`fdfl'.log"
log on

preserve

local grp 1
while `grp' <= `maxgrp' {

quietly summ niv50 if group==`grp'
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {local nivdsp = "0`recniv'"}
    else         {local nivdsp = "`recniv'"}
disp
disp
disp "Niv50 == `nivdsp'"
disp "-----------"
disp "(Observations: `obs')"
disp

keep if group==`grp'  /* This line can be removed but makes program faster */

/* OP Step 2. Probability of Exit */
/*--------------------------------*/
/* Prepare step 2 estimation: exit variable resetting */
quietly poly2 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly3 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly4 ntkinv ntqinv lnage lnapk1 lnapq1
gen byte _mark=.  /* Mark observations that will be missing in logit/probit estimation */
local i 1
while `i'<=31 {
    local ext="`i'"
    if `i'<10 {local ext="0`i'"}
    sort firm year
    quietly replace _mark=1 if _p`ext'==.
    local i = `i'+1
    }
sort firm year
quietly by firm: replace indsurvv=0 if indsurvv[_n+1]==0 & _mark[_n+1]==1
drop _mark

/* Begin actual step 2 estimation */
sort firm year
local rvars "indsurvv reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv _p*"
if `nivdsp'==12 {local rvars "indsurvv lnage lnapk1 lnapq1 ntkinv ntqinv _p*"} /* Niv12 would exhibit perfect prediction otherwise */
ollpak2a "`rvars'" "group==`grp' & year<91"
if `grp'==1 { est2vec prob, v(reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv _p* _cons) replace name(niv`nivdsp'bef91) }
else        { est2vec _tmp, addto(prob) nokeep replace name(niv`nivdsp'bef91)}
if e(N)~=. {
    predict _dpred if group==`grp' & year<91
    replace phatprob=_dpred if group==`grp' & year<91
    drop _dpred
    }
ollpak2a "`rvars'" "group==`grp' & year>91"
est2vec _tmp, addto(prob) nokeep replace name(niv`nivdsp'aft91)
if e(N)~=. {
    predict _dpred if group==`grp' & year>91
    replace phatprob=_dpred if group==`grp' & year>91
    drop _dpred
    }
ollpak2b "`rvars'" "group==`grp' & year<91"
if `grp'==1 { est2vec logt, v(`rvars' _cons) replace name(niv`nivdsp'bef91) }
else        { est2vec _tmp, addto(logt) nokeep replace name(niv`nivdsp'bef91)}
if e(N)~=. {
    predict _dpred if group==`grp' & year<91
    replace phatlogt=_dpred if group==`grp' & year<91
    drop _dpred
    }
ollpak2b "`rvars'" "group==`grp' & year>91"
est2vec _tmp, addto(logt) nokeep replace name(niv`nivdsp'aft91)
if e(N)~=. {
    predict _dpred if group==`grp' & year>91
    replace phatlogt=_dpred if group==`grp' & year>91
    drop _dpred
    }
drop _p*

corr indsurvv phat* if group==`grp'

sort firm year
save tmpsvv`grp', replace
restore, preserve
local grp =`grp'+1
}
restore

log off
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}
use tmpsvv1, clear
local grp 2
while `grp' <= `maxgrp' {
    append using tmpsvv`grp'
    local grp = `grp' +1    
    }
keep  firm year phat* indsurvv
order firm year phat* indsurvv
sort firm year
sort firm year
save "tfpest\estimate\coeff-survvprob-`ext'`fdfl'", replace

log on
disp
disp
disp "Overall correlation between Logit and Probit"
disp
corr indsurvv phat*

log close

preserve
foreach type in b se e {
    drop _all
    matsave prob_`type', path("tfpest\estimate\estmat\pfct") replace
    matrix drop prob_`type'
    drop _all
    matsave logt_`type', path("tfpest\estimate\estmat\pfct") replace
    matrix drop logt_`type'
}
restore

* STOP
disp "The program will now proceed to erase temporary files. Press ---break--- button to cancel."
more
local grp 1
while `grp' <= `maxgrp' {
    erase tmpsvv`grp'.dta
    local grp = `grp' +1    
    }
