version 7
set matsize 180
set more off
set logtype text

gprefs set window scheme monochrome
gprefs set window displaythick off
translator set gph2eps scheme monochrome


/* Choose Settings */
/*-----------------*/

local esttype "eop"

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


capture log close
log using "tfpest/summ/summ-revision.log", replace


/* OBSERVATION COUNTS */

use "brazprod/use-compl-`ext'`fdfl'", clear
gen byte niv50=int(niv100/100)
label var niv50 "Sector of Firm (NIV50)"
sort firm year
count
count if niv50==08 | niv50==14 | niv50==22 | niv50==26 | niv50==31


/* OBSERVED AND PREDICTED SURVIVAL */

use "tfpest/estimate/coeff$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear

disp in green "Data"
disp in green "----"
summ indsurvv phat* if niv50==08 | niv50==14 | niv50==22 | niv50==26 | niv50==31

keep if phatprob~=. & phatlogt~=.
disp in green "Estimation Sample"
disp in green "-----------------"
summ indsurvv phat* if niv50==08 | niv50==14 | niv50==22 | niv50==26 | niv50==31

disp in green "Correlations in Estimation Sample"
disp in green "---------------------------------"
corr indsurvv phat* if niv50==08 | niv50==14 | niv50==22 | niv50==26 | niv50==31


/* CHECKS ON Q-THEORY IMPLICATIONS */

mat checks = J(5,5,.)
mat colnames checks = niv08 niv14 niv22 niv26 niv31
mat rownames checks = bkdiff bsdiff kdiff tfpdiff corrtfpdem

use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
sort firm year
merge firm year using "tfpest/estimate/coeff-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", nokeep update
drop _merge 
order firm year niv50
if $out==1 {gen double fsize=exp(lnvaladd)
            label var fsize "Firm Size (Value Added)"}
if $out==2 {gen double fsize=exp(lnoutput)
            label var fsize "Firm Size (Output)"}
replace fsize=0 if fsize==.

drop if niv50<4  | niv50==.

* gen _chck=lnvaladd + lnapq1 + lnapk1 + lnlabfbl + lnlabfwh
* drop if _chck==.
* drop _*


/* Calculate TFP */

/* Individual Firms' Productivity Levels */
if "`esttype'" == "op" | "`esttype'" == "eop" {
if $fe~=2 {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed}
    }
}
else {
egen _secfe=mean(betafe), by(niv50)
if $out==1 {
    if $trd==3 {gen lntfp=-_secfe + lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=-_secfe + lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=-_secfe + lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=-_secfe + lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed}
    }
drop _secfe
}
}
if "`esttype'"=="ols" {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - olsbetintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - olsbetintm*lnintmed}
    }
}
if "`esttype'"=="fe" {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - wibetintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - wibetintm*lnintmed}
    }
}
if "`esttype'"=="gm" {
    local sgm = 1/3
    gen lntfp = lnvaladd - (1-`sgm')*log(exp(lnlabfwh) + exp(lnlabfbl)) - `sgm'*log(exp(lnapk1) + exp(lnapq1)) 
}
label var lntfp "Log TFP"


/* Table entries */

preserve
foreach niv in 08 14 22 26 31 { 
restore, preserve

keep if niv50==`niv'
keep firm year niv50 indsurvv betak betaq olsbetk olsbetq lnapk1 lnapq1 lntfp kletgril 

gen capital = exp(lnapk1) + exp(lnapq1)
replace capital = capital/1000000
label var capital "Total capital (BRL million)"

gen tfp = exp(lntfp)
replace tfp = tfp/1000
label var tfp "TFP (thousands)"

summ betak betaq olsbetk olsbetq capital lnapk1 lnapq1 tfp lntfp kletgril 

* olsbetk - betak
qui summ olsbetk
local olsbetk = `r(mean)'
qui summ betak
local betak = `r(mean)'
mat checks[rownumb(checks,"bkdiff"),colnumb(checks,"niv`niv'")] = `olsbetk' - `betak'

* olsbetq - betaq
qui summ olsbetq
local olsbetq = `r(mean)'
qui summ betaq
local betaq = `r(mean)'
mat checks[rownumb(checks,"bsdiff"),colnumb(checks,"niv`niv'")] = `olsbetq' - `betaq'

* kdiff
sort firm year
qui summ capital if indsurvv[_n+1]==0
local kexit = `r(mean)'
qui summ capital if indsurvv[_n+1]==1
local ksurvv = `r(mean)'
mat checks[rownumb(checks,"kdiff"),colnumb(checks,"niv`niv'")] = `kexit' - `ksurvv'

* tfpdiff
sort firm year
qui summ tfp if indsurvv[_n+1]==0
local tfpexit = `r(mean)'
qui summ tfp if indsurvv[_n+1]==1
local tfpsurvv = `r(mean)'
mat checks[rownumb(checks,"tfpdiff"),colnumb(checks,"niv`niv'")] = `tfpexit' - `tfpsurvv'

* corrtfpdem
corr tfp kletgril
mat checks[rownumb(checks,"corrtfpdem"),colnumb(checks,"niv`niv'")] = `r(rho)'

}  /* close `niv' loop */

restore

mat rename checks checks_tbl
est2tex checks, ready fancy p(c:/texdocs/tfpest/stata-origs) replace dropall

log close
