version 7

/* Choose Settings */
/*-----------------*/

foreach esttype in $esttype {

* local esttype "gm"
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */
/*        "eop": Expectations-extended Olley-Pakes */
/*        "gm" : Griliches-Mairesse */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Firm Characteristics */
/*----------------------*/
use "brazprod/use-compl-`ext'`fdfl'", clear
keep firm year niv100 indtype region uf age profit
sort firm year
merge firm using "brazprod/cgc-lig/firmhead", nokeep
keep firm year niv100 ind* cat* firstyr lastyr effextyr region uf age profit
drop indsctch indnoind
order firm year ind* niv100 effextyr firstyr lastyr cat* age profit
sort firm year
merge firm year using "tfpest/estimate/coeff-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", nokeep
drop _merge 
order firm year niv50 niv100 indtype age profit
drop if year>effextyr
if $out==1 {gen double fsize=exp(lnvaladd)
            label var fsize "Firm Size (Value Added)"}
if $out==2 {gen double fsize=exp(lnoutput)
            label var fsize "Firm Size (Output)"}
replace fsize=0 if fsize==.

drop if niv50<4  | niv50==. | region==.
replace region=0 if uf==35
replace region=1 if region==2
replace region=3 if region==4
drop if region==5
drop uf

gen _chck=lnvaladd + lnapq1 + lnapk1 + lnlabfbl + lnlabfwh
drop if _chck==.
drop _*


/* Calculate TFP */

/* Individual Firms' Productivity Levels */
if "`esttype'" == "op" | "`esttype'" == "eop" {
if $fe~=2 {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed}
    }
}
else {
egen _secfe=mean(betafe), by(niv50)
if $out==1 {
    if $trd==3 {gen lntfp=-_secfe + lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=-_secfe + lnvaladd - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=-_secfe + lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=-_secfe + lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed}
    }
drop _secfe
}
}
if "`esttype'"=="ols" {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - olsbetintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - olsbetk*lnapk1 - olsbetq*lnapq1 - olsbetbl*lnlabfbl - olsbetwh*lnlabfwh - olsbetintm*lnintmed}
    }
}
if "`esttype'"=="fe" {
if $out==1 {
    if $trd==3 {gen lntfp=lnvaladd - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - bklegri*kletgril}
    else       {gen lntfp=lnvaladd - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh}
    }
if $out==2 {
    if $trd==3 {gen lntfp=lnoutput - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - wibetintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp=lnoutput - wibetk*lnapk1 - wibetq*lnapq1 - wibetbl*lnlabfbl - wibetwh*lnlabfwh - wibetintm*lnintmed}
    }
}
if "`esttype'"=="gm" {
    local sgm = 1/3
    gen lntfp = lnvaladd - (1-`sgm')*log(exp(lnlabfwh) + exp(lnlabfbl)) - `sgm'*log(exp(lnapk1) + exp(lnapq1)) 
}
label var lntfp "Log TFP"

if "`esttype'" == "op" | "`esttype'" == "eop" {
    if $out==1 {gen double lnlp=lntfp + betak*lnapk1 + betaq*lnapq1 - (1-betabl-betawh)*log((exp(lnlabfwh)+exp(lnlabfbl)))}
    if $out==2 {gen double lnlp=lntfp + betak*lnapk1 + betaq*lnapq1 - (1-betabl-betawh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + betaintm*lnintmed}
}
if "`esttype'" == "ols" {
    if $out==1 {gen double lnlp = lntfp + olsbetk*lnapk1 + olsbetq*lnapq1 - (1-olsbetbl-olsbetwh)*log((exp(lnlabfwh)+exp(lnlabfbl)))}
    if $out==2 {gen double lnlp = lntfp + olsbetk*lnapk1 + olsbetq*lnapq1 - (1-olsbetbl-olsbetwh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + olsbetintm*lnintmed}
}
if "`esttype'" == "fe" {
    if $out==1 {gen double lnlp = lntfp + wibetk*lnapk1 + wibetq*lnapq1 - (1-wibetbl-wibetwh)*log((exp(lnlabfwh)+exp(lnlabfbl)))}
    if $out==2 {gen double lnlp = lntfp + wibetk*lnapk1 + wibetq*lnapq1 - (1-wibetbl-wibetwh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + wibetintm*lnintmed}
}
if "`esttype'" == "gm" {
    local sgm = 0
    gen lnlp = lnvaladd - (1-`sgm')*log(exp(lnlabfwh) + exp(lnlabfbl)) - `sgm'*log(exp(lnapk1) + exp(lnapq1)) 
}
label var lnlp "Log LP"

if "`esttype'" == "op" | "`esttype'" == "eop" { gen double bgkap = betakappa * kappa1 }
if "`esttype'" == "ols" { gen double bgkap = olskappa  * kappa1 }
if "`esttype'" == "fe"  { gen double bgkap = wikappa   * kappa1 }
if "`esttype'" == "gm"  { gen double bgkap = . }
label var bgkap "betak * gk * kappa"

if "`esttype'" == "op" | "`esttype'" == "eop" { gen double bgmu = betamu * mu }
if "`esttype'" == "ols" { gen double bgmu = olsmu  * mu }
if "`esttype'" == "fe"  { gen double bgmu = wimu   * mu }
if "`esttype'" == "gm"  { gen double bgmu = . }
label var bgmu "betam * gm * mu"

drop ph* obsnum olsnum winum bsdv* bcov* indsurvv ols* wi*
capture drop olstrd* witrd* btrd* 
drop lnap* lnlabfbl lnlabfwh beta* kappa* mu*
capture drop lnintmed
drop age effextyr-catlifsi
order firm year niv50 niv100 indtype region lntfp lnlp fsize

sort firm year
compress
save "tfpest/estimate/prodlevel-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

}
